-- HUMAN RESOURCE MACHINE PROGRAM --
-- 22-Fibonacci-Visitor - SIZE 16/19 - SPEED 126/156 --

    BUMPUP   9
a:
    INBOX   
    COPYTO   4
    COPYFROM 9
    COPYTO   0
    COPYTO   1
b:
    OUTBOX  
    COPYFROM 4
    SUB      1
    JUMPN    a
    COPYFROM 0
    ADD      1
    COPYTO   1
    SUB      0
    COPYTO   0
    JUMP     b


DEFINE LABEL 0
eJzjYWBgqEwJWK6f8SgiM8vZ6VHOe2P5vM9m0fl7bZ0rvMsUWrccBCphME993Pa9xruMYRSMglEwrAAA
hg4Sww;

DEFINE LABEL 1
eJxTZGBgOBHn7toWz+Npn2SdtTs5psk89da6Hykb9gGlGFgTZEP3JU0PeJtxyedW/vSAU6VacYyVf7Ia
Ko8WHqo4V+5ZNr1OvPBeM0NSaseUqCXtZampHbuqjSY9aWaY87CFZf7DFsEVT5pnr1/V+Hz71trPB1rL
9x5Xz3Y+8zfp4Cne2L3HL0f9OMwwCkbBKBgwAABDNkBj;

DEFINE LABEL 4
eJxTZ2BgCInS2wukGK5FFu6fFsnizBV3yWdHSlN+Ss6jiO5Sd1fGyoMO1dWi/ma1e7NLa0Vrt9dMXwNS
f3UBj+ezWe/7v01Zs/vH5ML9RtPUtr+Y+XnSiaUszopb6k7IbWU5G7f1x2GQWqNpqR1pmy5VgdiFdwO8
K28VJh+8frRQ9MKGCQbHZDeCxGsPyoYevC64QuZp90Whl9duMoyCUTAKaA4A3RFEcQ;

DEFINE LABEL 9
eJzjZmBg+F7T5a7X4O56s32DSURHqcWsdtlQzaZb64BSDCo5qdteNqpt15j1eAsDAZAyOzchf/r0gC1T
A7wPTjjqzNHn7kpIzygYBaNgYAEA4YAahA;

