-- HUMAN RESOURCE MACHINE PROGRAM --
-- 04-Scrambler-Handler - SIZE 19/7 - SPEED 19/21 --

-- Cheap tweak of @fd1e4020's solution: adding a JUMP makes it non-input specific

a:
    INBOX
    COPYTO   0
    INBOX
    OUTBOX
    COPYFROM 0
    OUTBOX
    INBOX
    COPYTO   0
    INBOX
    OUTBOX
    COPYFROM 0
    OUTBOX
    INBOX
    COPYTO   0
    INBOX
    OUTBOX
    COPYFROM 0
    OUTBOX
    JUMP     a
