-- HUMAN RESOURCE MACHINE PROGRAM --
-- 37-Scavenger-Chain - SIZE 44/8 - SPEED 56/63 --

a:
    INBOX
b:
    COPYTO   22
    COPYFROM [22]
    OUTBOX
    BUMPUP   22
    COPYFROM [22]
    JUMPN    a
--
    COPYTO   22
    COPYFROM [22]
    OUTBOX
    BUMPUP   22
    COPYFROM [22]
    JUMPN    a
--
    COPYTO   22
    COPYFROM [22]
    OUTBOX
    BUMPUP   22
    COPYFROM [22]
    JUMPN    a
--
    COPYTO   22
    COPYFROM [22]
    OUTBOX
    BUMPUP   22
    COPYFROM [22]
    JUMPN    a
--
    COPYTO   22
    COPYFROM [22]
    OUTBOX
    BUMPUP   22
    COPYFROM [22]
    JUMPN    a
--
    COPYTO   22
    COPYFROM [22]
    OUTBOX
    BUMPUP   22
    COPYFROM [22]
    JUMPN    a
--
    COPYTO   22
    COPYFROM [22]
    OUTBOX
    BUMPUP   22
    COPYFROM [22]
    JUMPN    a
--
    JUMP     b


DEFINE LABEL 22
eJxjZ2BgSK002VZQVTh9Um1F8qTaN5FAIQbdGiZ1hlEwCkbBsAcA+Z8I0g;
