-- HUMAN RESOURCE MACHINE PROGRAM --
-- 34-Vowel-Incinerator - SIZE 24/13 - SPEED 104/323 --

-- x0r & jthermit

    BUMPUP   5
    BUMPUP   5
    ADD      5
    COPYTO   6
    ADD      5
    COPYTO   5
    JUMP     d
a:
    ADD      6
    JUMPZ    i
    ADD      6
    JUMPZ    h
b:
c:
    COPYFROM 9
    OUTBOX  
d:
e:
f:
g:
h:
i:
    INBOX   
    COPYTO   9
    SUB      2
    JUMPN    a
    JUMPZ    g
    SUB      5
    JUMPN    b
    JUMPZ    f
    SUB      5
    JUMPZ    e
    JUMP     c


DEFINE LABEL 5
eJyTYWBgCHCRDQ11kg2NtVeLfmT7PjHZliFvkvOKrjOu9rPPuHIsmuQcskraQXJdtpXkuvcWEWsNLURX
A7UxzAmfXL0kZMvk1JC2BSC+f0y/F4h+lMNRIl6o199b4r6wtfwaWC1j5cmSwvRLKxiIBG7lG/b9qTI/
vKrR6MCVzsTNByd0Ld42ZU2vxRTBKoaJDHnnuv9kSbcfzEttDqjMaFrSDtIj1um9JKCbYQ5fj9Gki133
miM6eMoTWlkKtRub8r/UshSW1nKUFNSH1KDbtWDL8+3BOz8faNpvfWzO2T/H+i+ZH2a+vmZ3zc35m6xu
nVu670bpFO4rim23z16r/Xj0UtWh/aK1AbsSWqO36fUT659RMAoGKwAAXe91hQ;

DEFINE LABEL 6
eJwzYmBgaHd3dz3vIugTa1+YnGep2Oajd+++n27qEyGd50+vaj1/Olsj8SFQGYOP3uSVFabeSyIc2xaA
+Kohf2a8Czi56LPf7PVb/NbsNggwP7w8+M+x2+FVR4WiN+zriU3c3BnnvcQntmr6lKg1vakhWj2mfhsm
gPSm5OT25WVIrsvLUNuulbVmd2Ju7h7B4sydP6sFV1TUcCyqqLm1zqz23sZNdfc2gtTnT7efXTV5zW4Q
O2sm79LEOXtn3phfOLFtWWqH/crUDgYsYMEWhjlxW6evAbGjt63pPbM7punfgZCaisOitatOLGnHpgcG
lp+MaZp/5n3/ySv9y/7emL3e6taSrSDxeU+2mMs8bXKUeWo9Q+pZyKpLL9S2n3q9YV/zu7JDvz6WHfr0
xejAqu8rdqT9vLUOpL7xelep+W2WwrXfStPw2TcKRsFAAQCK1ZeY;

DEFINE LABEL 9
eJzzZGBgKDPL7Ttq4HzGxTDidrXJksdvLJ8/ve645LGzp+hNoDTDCuslkSBaOfTc0oWh3Rd9YnmXMiXW
zfqVvHPattSd0z6l1c0qTOdduiHd6IBROseFtxlNp0HqK2raFpTW8i4trkvc/L7+3v2Ceq0XW2szn3+v
WfIYJL+r+vOkXdV6/V9ql7RnNCm2BXVtmMA8wXnewQnuCw9OOLe0pX/6moDuJVuvdahtB6lPmZ3ZvXh2
3awHcwRXzJ43f9Pkha93+Sx5v5dpxfu9ZWueb89bf2vdqw3nlmpuNJu6YuPBOQu2SK67vl1te8AuiP6g
i7KhApfWxJ+7tHcm95WQVe5XEzczX3++3fTOih2f76RuA6nZdFS2OfXU5Grpc/0V3FdOlujeZylkQAKP
Hh2co/TYegaI/e3w0cJ7Z+pyNt4tTZN5WprGMApGwRAEAMOTnpk;

