-- HUMAN RESOURCE MACHINE PROGRAM --
-- 29-Storage-Floor - SIZE 22/5 - SPEED 20/25 --

-- Based on 21.21.unroll-mrflip.asm with input before jump trick.

    INBOX   
a:
    COPYTO   10
    COPYFROM [10]
    OUTBOX  
    INBOX   
    COPYTO   10
    COPYFROM [10]
    OUTBOX  
    INBOX   
    COPYTO   10
    COPYFROM [10]
    OUTBOX  
    INBOX   
    COPYTO   10
    COPYFROM [10]
    OUTBOX  
    INBOX   
    COPYTO   10
    COPYFROM [10]
    OUTBOX  
    INBOX   
    JUMP     a


DEFINE LABEL 10
eJzTZGBgyAp63LYm8Pn29QEcF0r93r8u9fvxsdy36vNOnxXPdvqUHfrsl9mdH3CrYUkIR8nE6LqcY/HW
WU6J1lnbUjlKjNIj6o3Sn3dWpuycZpO8d+accNHVqiERa4HGMjRXHHSYXNRfIVlwchGI/yLrXihLxa2g
Nw0hftLtIX4gsWsdkg1XOp93Xus4uWh6x85pF7vuNbf3HczbN9Eo5dsUvUTV2X+yGEbBKBgFNAMAfANM
sQ;

