-- HUMAN RESOURCE MACHINE PROGRAM --
-- 41-Sorting-Floor - SIZE 20/34 - SPEED 648/714 --

-- A simple tweak of @sniperrifle's solution        

a:
b:
    BUMPUP   24
    INBOX   
    JUMPZ    d
    COPYTO   [24]
    JUMP     a
c:
    COMMENT  0
    COPYFROM [22]
    OUTBOX  
    COPYFROM [24]
    COPYTO   [22]
d:
    COMMENT  2
    BUMPDN   24
    JUMPZ    b
    COPYTO   23
e:
    COPYTO   22
f:
    BUMPDN   23
    JUMPZ    c
    COPYFROM [22]
    SUB      [23]
    JUMPN    f
    COMMENT  1
    COPYFROM 23
    JUMP     e


DEFINE COMMENT 0
eJzzY2Bg2Gaj7bnQ+qZ7qNV577tmgTGBRg/T5HRX1VToSExt0O9e/chQYUu+Wdzem9bLDuU6Lzzyy/3u
mjrPwAV1ntbtp7yuZ6l4WaTJuPvE3XE+6g80jiEwcdNsycSajQcSBXcppSw8kpf6+WhI5o/D77KZDjDn
8uyJKGSZa1eaP6W7bMX87rLVB66XO558U/H+OEhvb7dKXkOvYfeZvra1khMUtryaJLajbLrgriULM3Y2
LSraClJzYvLpiT0z1Pvtluj0gvihuzhnO+yctbR3F+tD4938d9/v2TT7+36WuRMOLV6YduDklrkHmA6w
7PtxOHTXwiMg9VXnPJYonH+zLPeC4C6vizx72C7z7Mm4enkD37X5iy1vZOzce3PZIZC6+teraqa+ObmF
5a3YjuMfd+0CiZl96l699uvHJQyjYBQMEwAAz9uT8w;

DEFINE COMMENT 1
eJwzYGBgWB99yneDX2tmoffhoq2eP+pPebk2fwg069wed7U3o7xyAlAJw+TKzKBnXZlBIPbt+rL8uRNP
FGQsC64F8UW3r69atPtEAc/BXzHsx+653jjBb6R66oGS6ilJvX1nmjzaz8xMNL3wNU7j0ppIyxtLrWbf
SjN0vM1mVnFbxp/r9p2MLzf3lcy+taUCZNaeZ6+T9jw7mwdi+z77ZAuiJd+dzQt4x13h/EEvC8Rv/swb
mvmdOZL/h0AZwygYBaOAIgAACWFT6Q;

DEFINE COMMENT 2
eJzzYGBgOKq7LdREzz3BRE9/3VHdmo1AIYZiQxn/ZWbigcx28+LL3LgrDD1cm2XcSybdcf64RMDm7ppi
w127juq2rWUxPLINpD45qq5vfqjdCoPQG+smhZdvlos5uYUlQXVTR+LdNfpJPou+J5ZMEox72fo8+nMj
SP2T0u0zE0p+LfAuZjogXHx5Q0LJt0VMVc098nVKE4/Wpc4wqb+84UPDwiN/634cBqlf1f98xbIp8xdP
mS0xddusq73s0ye17Z5q3f6nm3P2/Japy1+3Tl0+q/PumjN9ybs3T+LZEzO7aCtI34f1m00YtrGZtZ/p
cZlztslj47nMoJSzTkmqp3KKjU58brQ/dr/zxCGliR57+GbO2/z3YNAmo/MM25SvgvQ27Gn/yDAKRsEw
BwDGuITc;

DEFINE LABEL 22
eJxTYWBg+Oiy+oCMu/MycZ/eDqFA9wSD0IbsqPA5TZPC+Wa6hrHvqw3rO3MvYs4x49hzm8xTXZufZhhn
CGQvjtXNL8sXLj449XyJ2I7gsh+HgUYxnGvcPtO2KXI/iB3fmFQOohnau1cndSpsmdXpf3hW59Y9xj3R
c+L6mns6JtzvjJysNHHmtP/zyqbrr2Of7g82gxZg+uLtMxMWH5vsvahyQv8C9f4Hc2Qn189imZs5s3v1
wpmrD8TM/nxUd96rk02LPh8FqWfdKDu5ZGPWtNUbxXb82HRkG++Wmo33toXNk9slMXXRbompq/alzjA7
bLLG7LDCFueDC4/wHHx6WvGQF1jvmstJ5WsuO7RqXNJfp3Fp/47Sy5NPtd58cPbAQ6PzvI/Nz/I+fnUS
pE7hvM8i/UfbZ9LKz6NgFBADAKNMjlM;

DEFINE LABEL 23
eJyLZ2BgUFAQMaiU97R9ILMt9IFMV3qwxK3up+Ldq4FSDDHSixdaycxaWik/a2mcwYr5ILEZrnOavF1c
m7/Z/5+3337+4isOj1aJuJzcUuYmtiPGS2xHpd/JLeH+qps2+G2fecqLrQqkpziht0Mt3qzzT8zV3vXR
HkvkYtrWbo8r2no1KXe7UsqRbT5pj1btTpu11Ccta9r/lAv9jxIcWkH6NEuEgktLf9SXlkbP2VUsuGtX
cflmkPiC8uae+MZ3zTWtf2pBfMdand7wOrsVi+vPbeJtfXAWJNa/4HPjkoXbZ+YubFxfNX//Dom5VVdM
F+7f0bV06nKQvOnCm+4gOmfdu2ah9bnb/65dfUB+7YZ90zZ4LGnZbt2etTuimudgXR/PwU2zA/YL7gKp
/XferFP3rHq/+8nFC41O6K/jPym2Q/VU5H7/M15Hq859Ptp0kX1f8JWajfOv/lpw6Ip6/5tr+usKbuzf
sffmysd8134/+XSE677egexbe7afucowCkbBIAAAyuey1Q;

DEFINE LABEL 24
eJzzZ2BgqJTfbFIndSmnW+L/PCCXoVti8cLNJr8WLLT+tijVwXkZSMw04H4nZ/ST9uSoLRUnw1Xy0kO7
0qVDLNL++p8o6PPnrgj3f9Ke4qu/7kPg/h3XQiP3vw6L3A/S9zvTodU9+/RE92zpbQuzZi2VyFvY8K8w
p9i7WLSEv8Ksc2vFptnXy4u2gtQ2T/WvnzD5c2Nxf11fcf/8xd8n3F0TOVlrQ/PUR6vWTV8x32jmwak3
Zj5pj5nd3PNgzsGp3+Z+XPJtrseLZVM23z/Td+YqyIySjXkBH9ar5H1Y/7nRZqNOr+h2lrmS+x+t4jlo
subVQctVegc8loDUha3NKX62U7RE70BhIYifeWJb6LaT20ILT3elfztzY13uhe0zn1xmrMm4KlA26fq+
kue3/esb713tZX0wf/HZ+yZrdtw7t4lhFIyCYQAA9bCcCQ;

