-- HUMAN RESOURCE MACHINE PROGRAM --
-- 40-Prime-Factory - SIZE 23/28 - SPEED 427/399 --

    COPYFROM 24
a:
    COPYTO   1
    BUMPUP   1
    INBOX   
    COPYTO   0
b:
    BUMPUP   1
c:
    COPYFROM 24
    COPYTO   5
    COPYFROM 0
d:
    SUB      1
    JUMPN    b
    COPYTO   6
    BUMPUP   5
    COPYFROM 6
    JUMPZ    e
    JUMP     d
e:
    COPYFROM 1
    OUTBOX  
    BUMPDN   5
    JUMPZ    a
    BUMPUP   5
    COPYTO   0
    JUMP     c


DEFINE LABEL 0
eJyzYGBgmCfN42kvLRkUIzN9DZDL4Km/t+moQciqZsPpaxYYFU4MM9vbxGMlWrvUJqJe0e5e8327FV0N
doIrQGpn+Tg7zfK5tQ7E/unj3L48WLRWKuJzdWF0RP3q2JPdXHGP5/rEqi3QjyldLRVxa92ZQIja4qKq
hri82Y3s2Su6ujNjZnZnrlnimTV9jWNu4uZb+YmbT5WWrmapeDw3ucJ6BkuFXv+p0rbO7FLFtktFe5tA
+sU6fXY3TZg/O3Tq655301M71sy417x49qUqkNyVzv4Kg+khq64umH2MYRSMglGAFwAA6EleSw;

DEFINE LABEL 1
eJwLYmBgSBbn8UwWf7ASyGR4LiphXy753IFZ47kDA1jOuPy9ak0JiD3bmqmy2JypMt3oe9N1vchJ3Xoy
89gNfqxIN1q/+rLl9DXJto7LJtulzXa3W9eabMtUmWxb237Y/u0mkN5pkZeqzMKNy6ODvcvWBzBVbveN
qOf2vtxb7KUxpdhr98LF3j9WbPf1W78+gHVTUJjfeqcYzeUgfXbpnraf0nZmdKWnlHalL16klDF9zavM
JVulsru3LSrs3naqFGK+UsaU4ktFEHe6de2sFuu8VJXV1lm7r/lYy7fGrgnfGgWm3mqSmfeu5ceKuo76
tXa99WvNJvxY8WjS5QVCU6bNFJoiMFVvsknXuQkODdd6L1WVdV+qApn1cf63/Mj5a4sOzjPbAOLbLjjW
krrkUlXhyrVFvmunFCeu9y77uZ6pkoFEwHnBPpdUPcSAOTerGlY+2NtEC7NHwfAEAKqIkvk;

DEFINE LABEL 5
eJyLZmBgKBac51ws6F12W6Cgrl/gxwqgEIMIv4T9YqFJVs9FD1t8ljps0SzH4PBf3tZ9usJhb2+F9nBz
Oaa0YNkFmdFSfPnGYncL/EWnFOfLpHZIy2tMqVbsWgwyw1jzdU++/uXezUYy3fGm/E3xpsbl5w2PFvLr
Timu1zQu367eWduutq61XS1y0nMNmXn8ug9WduutXy1semIVSP97b778xd4F2dXuBdmbXdXylJ2kK647
fm9Kd2XukfeNnFTvXzfrtP/iRYu909Y5e7JuCnZ+uynfSXYjSG9RbEF2UaxDQ1+MSVdfjOAKtdj1q5kS
/dbfS/Fbz5Z5YpVZlubyRznTZh7LXdQfl+ddVpW7IPNRTnhOXN661m95guAwuFb1XPda1cu0rqqd1Z8q
+ZvsqpZsBYmLdaqYGnVMKZ7V7l3G1H6sxa+9aMmvzreb+Hqid8zr19rlNDV6B0jduk7vMrZ+43KzCSml
fVNTShlGwSgYhAAALV+PZg;

DEFINE LABEL 6
eJzLZ2BgCBcysFssFBbJLXQk7ju/75zv/P6HgMIMi4XaXN4LMThsF5lk9VlKxfS17GezakVPW3UVHk9u
VaOUYhW+/Hilzlp2WZOu9eLMPcZiJl3ZIsda/EW/N92XqG0/LMnc819eZt53pelr9qsI7QaZaW54fPpj
42kzL1tOm5ls+2Oqtv2i/sP2qR3l9g4N7nYLa/ytmSoXWzBVxpteqvpvpN742uB1z279tNm79X+smG8Q
vWOz0Yz9zmZsR2dbvztq7whxJ7c3UyW397GW9967+t57yx0Bu927tr3eP6J+fUBE/fLgS1XXQy5VzQuL
qJ8WqTFFL2rGfpCaR5Gve27FqDdyxUXU/0peWMOX5tBwLd2nc1dG5KRdGQ0HQGq+NRbUCTUurNlV3Vkb
VTm1LalMYOqzksWLnpUs2fqrrOFAVOXVY2a1e4/rNfgfKmp+u6mtVWbetrajhXJtKaVybetamdrXrzbq
SD8IMqtqMl++0JTISaumHJ++asrDPSAxr0m27iA6cNGCzMBFl6peLvre9HIRxO7GxUyVscvvFuxdyZe/
dc3dgpPrUkqXbkrtsN0sMNV2s9YuhlEwCqgAAMdcu+Y;

DEFINE LABEL 24
eJxzZWBgSJFMdeZSTnVerKro+N/I2em/0QrXowbWweJaTfk2Gpeq5NVFa11UUzvUVVZ0ZSoXTtws775w
mlzX4hgZ+00xMhw7p8lx7CxUWLL1gFrTljp1+023TGQ3Ao1lKHCpm3XHu25WV9DkSR7BARM8glM7uoIY
WgMCqhoy3Gc3ervdaz7vEjDhvEvMzAz36WsWeS7Zut/r6DZrn9w9pX6fDzSGXtoPMkc+6XP1gUTevl/J
906A+JEpMTMjU65NMUnT6z+bcbJ7RZZi2/cCs7rnZWZ1IPl/E2c3evRVNcxqT+1gbJ086Unz47nOLfab
ElqfbxfrND9s3FV19N/Eeye4Z+buYZojuzFxzvzZ7bMKJ26ZuqLLo+9eM8iMTc7vE3td1aLVPA6Gz/Ip
9Pno/9qdYRSMgmEIAJP1gPM;

