-- HUMAN RESOURCE MACHINE PROGRAM --
-- 22-Fibonacci-Visitor - SIZE 15/19 - SPEED 126/156 --

    BUMPUP   9
a:
    INBOX   
    COPYTO   8
    COPYFROM 9
    COPYTO   3
    OUTBOX
    COPYFROM 9
    COPYTO   4
    OUTBOX
    BUMPUP   3
b:
    ADD      4
    COPYTO   3
    SUB      4
    COPYTO   4
    OUTBOX  
    COPYFROM 8
    SUB      3
    JUMPN    a
    COPYFROM 3
    JUMP     b


DEFINE LABEL 3
eJwzZmBgsA0WDwwK2Ra6JvjNsq4Qo/OswflTHgc/SzEIbXdLD2UWrQ3jFbwYtYt/ZvoMWaByBsfaAt2f
ZROdNEvyAvoLH6a9LBAo21ggMXVp0aNVbKViOwzLI/fXVfgfZqpadgik3rVVtCSq7Vb3pLY3y/LbPy7x
7Vg790+3fAFL/7OUqxN3lk2YrDSRffqNdYnT9u8AqXeav9QqYsFSq9yFnrY6q8Oibq9rzQzaVNfXuWn+
4qBNR7btWN935u/aaxdfzv/2jAHs/vVVnNHrqxhGwSgYBSQDAIH7Wzg;

DEFINE LABEL 4
eJwzZWBg+OiSNe2jS0oIu1uisaHHT4nJXlEiff4zZBcHmCsBpRlSHdS8cwLOe4PY7tlzpUMys/W10n/F
3E1d2OCTVjkhMX3t3IVZdisk8vTXORfcWNdUfHcNSO2KqpmJX6sLC1Nq6vrWNAXGzG/ZHazctibyXrtF
2qzO3g6QGu75Jwp+bHqYBmLnHY4Pm3H0Wcrh4wsbDh//Pw8kdufCRY0VNzxtX31ozWT/uq+E/8fLVvcf
22f++ta43u7rhn0RHx1Pbn/dcqHl2cXLwhdFbhud2HubYRSMglFANAAAft9hXg;

DEFINE LABEL 8
eJyTYmBg+BCYF8AaXDJpWtDfg4GJn49WJ/sfBgozpNR8bnSsNT+bUsN0AMTfUJsSAqKbp0buF5n64Gzz
1Ocr7Kdbt4fMeNkqMMu6/cq8ygm7FuVPsdi2afb+/Ztmq+39tih0V+N63+2d5xhGwSgYBYMSAAB0Di+V
;

DEFINE LABEL 9
eJxTYWBgiPGyd7T0VvMu9L6eleJ7bhNQiOGyr5Xz8ojrWS7JvxaYp+qv00p/s2xh1o96geyzecy5xX4g
NWIdK6KXt3d0aXd+XBLanbHzfW/ybskJPHvMp4jt2DZLf92+uVOXH1/AN/PjIsaahMX9qSA9LPvkC2L3
su/r2H/oZuShtDs+R/beLjwtd33+VZvTW6/1nWEYBaNgFNAVAAB+UUDh;

