-- HUMAN RESOURCE MACHINE PROGRAM --
-- 20-Multiplication-Workshop - SIZE 14/15 - SPEED 163/109 --

    JUMP     b
a:
    COPYFROM 2
    OUTBOX  
b:
    INBOX
    COPYTO   0
    INBOX
    COPYTO   1
    SUB      1
c:
    COPYTO   2
    BUMPDN   1
    JUMPN    a
    COPYFROM 2
    ADD      0
    JUMP     c


DEFINE LABEL 0
eJyrYWBg2M6WuNmMXXLdF/a92QacjyJyuRQjsrgLk+/xSzbcFGwrEhaxzvIVK01zkjJKYZCuy6mXllwH
1MawQE2v/4Fa/7I49ckrp2nFbLigE7PhlF7EWhfDqukuhhsmgNRkWK+Jf2LzfDuI7eqhFcfmcTDviEdA
pbMnxyIHryVbQeKTnF/3sHlkdq8PeN0D4k+JUuucGH1uKYgdHmmdBaJ3pDzvNEpX2qKTWXV0dabPJZCY
UXpmd2aWYpt8nmKbSJFWz6UivX7+kp3T/ErcFwYXnVuakgMxo7RWLdq4bkl7Qf2PqQX19zaCxM5132s+
1z15pW8PhH+xa0sqiJ49b3pd4pxLVWtm3Gsumpbb93nqzmlG004uyplxaYX8XMl1lxfeWnd28bXVILVh
OyZXR2wXrFq0WbAqe4No7YZ181s+rc3sNlzHsej9Ot6lmRsvrYjeNnml5PaA5TO2ty24vv15Z9iOprlu
+2I2gPTnHu+vUDtVN0vtFCQ8H56e36JwRrJhzlnBqunn+yuYr/dX7LshWLX7pmjtj1v3mn/c2jnt7w2I
XrsPl6pY3gVU9r2SbLjxzHqG+HOORUIvQ1YxvRdd/edDwHKbj1sm7/2wYYLdh0cRIPW/PtrPNvkyfQ3D
KBgFaAAA0JPWag;

DEFINE LABEL 1
eJyLY2BgMOCU3biKe0l7lGBuQrjQltSLIrl9HBK3GhikL1V9lv+TtVFhduNGhf5l+oqiq4HKGfh1f0z1
0YtYy6Ufs+GAUcwGS1PJdcXmgisMLcymguSvOJmlX3FS2gJiGwR8T88NfN2zJvDeRhD/p8/7/jnh7/tB
bPuk1z0MSRyLmBLnbwLxfyWfLAHRk4s2TAgr5F0aVli4f0aB+3mQ2ITiJe1+JQmtjJUxTd9rZJvX16/o
etOwc9raBt6lm+pEV2+tnb6mtwTivqAurbigrsnVAt3WM870QMxeM2N+i9ZMtc7XMy6teDEzZgNEzCwd
RDuueN9ftubzpNUbCic+36jVk7ZJsW3pJp5y9U3uxZvXMuRVrmbIO7CCpdB9WX8F19L5LVxLzy1tXq60
xWRt7h6dDbl7ErYkbgaZ03BAsqH2oCzYn38ORtRXHOYpn3+mq/TyBdFa/0tL2iFqRGsbDniXMYyCUTBI
AAD2lpeJ;

DEFINE LABEL 2
eJxLYmBgWMOVGpXLNbsxi3vLQSCX4RmPWvQTXsUIVknFiB+y7xNL5BnySuS9y3bKXqvdJ32r4aS4bLM2
t2wzSG23HsMcHr35m/h1c/eA+H66md1ndUVXe+qbHwbxO/SrpjcYbZhQbJ7ZnW31ukfRrnQKSNzWe8ME
V4+9Mz3cRVcfd1fa4uyptavW+/1eC9/C/SuD3u+dEz57/Zxw7yVJoX9mZAWVTvnmu2UySJ983s5piblb
JudlvO83Sn/fX5lSOmV38t6Zu5P7l+1IUdqikvPj8P3c3D1z8+5tnJvHsWhBbumUuDyz9Oh854Jb+akd
wUX3Nk4oXrO7u/TzAZB5xnWlU4rrQlblNqzYodm0ZndyS+6eKZ3zN03qmr2+v/vofJCa/u6Dc0C0b0/V
dL4eiPtFF26YkDJ7Te+Lmbl9+dOtZ3yeOn3Nh2nzN2nNXLJ15vzUbZcXPt4ycdH8TSC1SzelRi3Y8mPq
gi2TV97ZmrkTJLZ71fNOmW1qnQ4H9Po/Hn3fzzAKRsEAAQDTM6uH;

DEFINE LABEL 9
eJxLZWBgWGpzz+5BaK7R18hco81RG0ykIhQd2UIm+5530SoNM3s897+R0coFRtPX3DK5te6Od9OWIyFN
Wx6E2m+qjJDdCNTO0J3ZX/EoZ/7sV5knu03SjhaWpU5Pv5rqHpOXMT+MpzTAe2rtPTuQugW5Gyr9SnLL
r9csKQDxRYqsZyRX1M1ybomZCeIf6a8LrZp8tHDL1BVdoVN5+5b39VcEdK+JN+6SDLrSudd2UpeZ5ZF+
b8N30/uMn836bPZrnqKj+IKTbuILJvvazOuK05i1M8Ng+p8spjnPix4tr2oAmVmx/XvAn60sUXZbS9Pu
bzlaaLd1RVfFdusZb3aHrHqyT3bjx6M+u5tOP98ufa5pS+iFW+suXhRc4Xv54BzuKye711ze21R08Whh
1TnB5JcnrIPXH7vmz3ig0GfVnmv+FdsfRYD98GLnWhD9/I19rt0HM0u7D891G95rGTx/c9LN75V9bthz
s7rvzxhaQWr2Ptm5dsaz6WsmvPyz/tILn90iL/r3fn+Wu8fyGcdOy2dNW8Ke228Ke86xk2EUjAI6AgDO
V8Uh;
