-- HUMAN RESOURCE MACHINE PROGRAM --
-- 30-String-Storage-Floor - SIZE 7/7 - SPEED 203/203 --

a:
    INBOX   
    COPYTO   24
b:
    COPYFROM [24]
    JUMPZ    a
    OUTBOX  
    BUMPUP   24
    JUMP     b


DEFINE LABEL 24
eJxzZ2BguKqlFRej8TouU/l7+gcF+1wjhaOFRgqCVesUjSatVrKesUzl6PwQ7aPz+XXdF/roHZ3PbvB5
Uoe+Vs9Z3fktZ3UnV3Pp/8k6oX8wr0Ofo4TFMKTG0eh5Z4FF/7ICi2urgcYzfPYTVTT2/2z2LoDFOT3Y
Ois1JKTmWbBss0HAyUVb/LyXeLh3LeZ2a1twxtV+trdbQiubh2CVsf/JkjWB3mUg/Y9yQhQUc61t7uYt
iQwrdC8WKcrsnlGwd+ajnJOL0rK7Fmdm7Z1plL5hwrbUmKa3GQx56tnf0xfn7MwA6V3VaJSS0VSVubwp
pim78cfUl41tC940iNauajxa+LBFL/FOm2TQzfbJvlc6A7y7er09HCbyeIL08S7J7GYYBaNgBAAAysV1
tw;

