-- HUMAN RESOURCE MACHINE PROGRAM --
-- 20-Multiplication-Workshop - SIZE 28/15 - SPEED 98/109 --

    JUMP     f
a:
    OUTBOX  
    INBOX   
    JUMP     e
b:
c:
    COPYFROM 5
d:
    OUTBOX  
e:
f:
    COMMENT  0
    INBOX   
    JUMPZ    a
    COPYTO   0
    INBOX   
    JUMPZ    d
    COPYTO   1
    SUB      0
    JUMPN    h
    COPYFROM 1
g:
    COPYTO   5
    BUMPDN   0
    JUMPZ    b
    COPYFROM 5
    ADD      1
    JUMP     g
h:
    COPYFROM 0
i:
    COPYTO   5
    BUMPDN   1
    JUMPZ    c
    COPYFROM 5
    ADD      0
    JUMP     i


DEFINE COMMENT 0
eJxjYBgFo2AUjGQAAAQEAAE;

DEFINE LABEL 0
eJzjZ2BgOFBXHSlbp53cXnMpV6ds/qT/RUs3xBS57AFKMVxtjo6d2cHRptIttvhFv8ghkNj8qvapMzva
pzIQAUL7D5szT2C33zOp2ltu6v6gxul3QkHii+ZKOaZOuhPKMZE5yr9PIRYk1ji93qBxOmcZiL2sb2vg
xFmXQj7P+RnBsoA3GiSWPdmq+l/f9AX/+uTX803S2KA5vWxH2dJXR0Byexft6AiYJzn57NQjB1InqZ4G
iV1v/7FKr+P28uXzTneB+Js3lOoHrjtj0b7iUSHYDWvzUhM35qUG7mOOqjj6M+LW8WdhIHHug7YJv/YK
ly/eW9L4frfSlCc7py9o2n57+f91ydvmrlm+t2flrv0gdWHr17Vv3rCuXWEr68Sve9w2qx3TO/P0ZM2V
oHOLbxATNqNgFAwGAABrnohP;

DEFINE LABEL 1
eJwTZWBg+F/0xOd/0eSLQCZDYTmvh3HzG++9rUcCmNuLo5jbjZP2tr7KYm2orDhcztAeWfmho6X5Qo9N
5/KJu3vKpzP0qS1c3zt3Y2ZP6Tbvxi9HOSpPn2IYBaNgFAwZAABehCbo;

DEFINE LABEL 5
eJzjZmBgsChtLN/d01kGZDK0NH/1eth0xe9t46H8OY18S+ybardKt5rsO94tc5BhmIDG5VbVk1ZZVYPZ
01ctmrtn1SIQe9KqVp93q7cGrlh3o0Bqy917ILG16yO3uq2J3Lppgerp6bNnXgeJndxisynp4PK9J49c
PwTiv5gVXjdQfhkFo4BSAABN4TlL;

