-- HUMAN RESOURCE MACHINE PROGRAM --
-- 09-Zero-Preservation-Initiative - SIZE 18/5 - SPEED 16/25 --

-- This solution is level-specific (patterned and quantity-limited input).

    INBOX   
    INBOX   
    OUTBOX  
    INBOX   
    JUMPZ    a
    JUMP     b
a:
    OUTBOX  
b:
    INBOX   
    INBOX   
    OUTBOX  
    INBOX   
    OUTBOX  
    INBOX   
    JUMPZ    c
    JUMP     d
c:
    OUTBOX  
d:
    INBOX   
    OUTBOX  

