-- HUMAN RESOURCE MACHINE PROGRAM --
-- 19-Countdown - SIZE 61/10 - SPEED 65/82 --

-- This solution is level-specific (quality-limited input) and assumes inbox
-- items with value of no less than -9 or greater than 9.

    JUMP     t
a:
b:
c:
d:
e:
f:
g:
h:
i:
j:
k:
l:
m:
n:
o:
p:
q:
r:
s:
    OUTBOX  
t:
    INBOX   
    JUMPN    u
    JUMPZ    s
    COPYTO   0
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    b
    OUTBOX  
    BUMPDN   0
    JUMPZ    c
    OUTBOX  
    BUMPDN   0
    JUMPZ    d
    OUTBOX  
    BUMPDN   0
    JUMPZ    e
    OUTBOX  
    BUMPDN   0
    JUMPZ    f
    OUTBOX  
    BUMPDN   0
    JUMPZ    g
    OUTBOX  
    BUMPDN   0
    JUMPZ    h
    OUTBOX  
    BUMPDN   0
    JUMPZ    i
u:
    COPYTO   0
    OUTBOX  
    BUMPUP   0
    JUMPZ    j
    OUTBOX  
    BUMPUP   0
    JUMPZ    k
    OUTBOX  
    BUMPUP   0
    JUMPZ    l
    OUTBOX  
    BUMPUP   0
    JUMPZ    m
    OUTBOX  
    BUMPUP   0
    JUMPZ    n
    OUTBOX  
    BUMPUP   0
    JUMPZ    o
    OUTBOX  
    BUMPUP   0
    JUMPZ    p
    OUTBOX  
    BUMPUP   0
    JUMPZ    q
    OUTBOX  
    BUMPUP   0
    JUMPZ    r

