-- HUMAN RESOURCE MACHINE PROGRAM --
-- 32-Inventory-Report - SIZE 16/16 - SPEED 31/393 --

-- Relies on a fixed floor where occurrences are: A=4, B=5, C=2, X=3

    BUMPUP   14
    BUMPUP   14
    COPYTO   13
    BUMPUP   13
    JUMP     d
a:
    ADD      13
    ADD      13
b:
c:
    OUTBOX  
d:
    INBOX   
    SUB      10
    JUMPN    a
    JUMPZ    e
    COPYFROM 13
    JUMP     c
e:
    COPYFROM 14
    JUMP     b

