-- HUMAN RESOURCE MACHINE PROGRAM --
-- 21-Zero-Terminated-Sum - SIZE 35/10 - SPEED 61/72 --

-- This solution is superseded by 26.56.specific-AaronKnowles.asm being
-- functionally same with further optimization.

    JUMP     h
a:
b:
c:
d:
e:
f:
g:
    COPYFROM 4
    OUTBOX  
h:
    INBOX   
    JUMPZ    j
i:
    COPYTO   4
    INBOX   
    JUMPZ    b
    ADD      4
    COPYTO   4
    INBOX   
    JUMPZ    g
    ADD      4
    COPYTO   4
    INBOX   
    JUMPZ    d
    ADD      4
    COPYTO   4
    INBOX   
    JUMPZ    f
    ADD      4
    COPYTO   4
    INBOX   
    JUMPZ    e
    ADD      4
    COPYTO   4
    INBOX   
    JUMPZ    c
    ADD      4
    COPYTO   4
    JUMP     a
j:
k:
    OUTBOX  
    INBOX   
    JUMPZ    k
    JUMP     i


DEFINE LABEL 4
eJyzZmBgqNAoDfiqvthjvkqkNYeihOlOuQCTt0ISpjf5N9qG8Yf4PhDYFvZW6HvMDMnKzC+yn/LOKspU
Ple9392qtXVNq9aJXb81Zh7arL7r6C3lWyfWyNw6cUxs5iE94RO7pAXero4R+DQTaAVDhPkKM1kLGb9U
S//4tVZpG79Zm+90tXuxd5bjxYNbXRMP73abeYjL8/9Oce+pK+94S5iC9OhEfDyiE2G8ICFMpnJ26BO/
2aG33V+FF5hLxE8Nlk94F5qe+C70R7JaqHuabeDiEgnTVaX6hhvLvhuWlVtYNFe2xzVXxtb/LH85aXHJ
tfUKJY4HGEbBKBgFGAAAnKFndQ;

