-- HUMAN RESOURCE MACHINE PROGRAM --
-- 40-Prime-Factory - SIZE 127/28 - SPEED 54/399 --

-- This solution is level-specific (quality-limited input) and assumes inbox
-- item values of 25 or less due to largest prime factor, excluding the item
-- itself, being 11. (26 = 2 * 13)

    BUMPUP   24
    COPYTO   23
    BUMPUP   23
    COPYTO   22
    BUMPUP   22
    ADD      23
    COPYTO   21
    ADD      21
    COPYTO   20
    BUMPUP   20
a:
b:
c:
d:
e:
f:
g:
h:
i:
j:
k:
l:
m:
n:
o:
    INBOX   
    SUB      20
    JUMPN    ab
    SUB      21
    JUMPN    u
    SUB      22
    JUMPN    q
    SUB      24
    JUMPN    p
    COPYFROM 23
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    COPYFROM 21
    OUTBOX  
    JUMP     a
p:
    COPYFROM 20
    ADD      20
    SUB      22
    OUTBOX  
    JUMP     o
q:
    ADD      24
    JUMPN    s
    COPYFROM 23
    OUTBOX  
r:
    COPYFROM 22
    OUTBOX  
    COPYFROM 22
    OUTBOX  
    JUMP     g
s:
    ADD      24
    JUMPN    t
    COPYFROM 20
    ADD      22
    ADD      22
    OUTBOX  
    JUMP     n
t:
    COPYFROM 23
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    JUMP     m
u:
    ADD      22
    JUMPN    x
    SUB      24
    JUMPN    w
    SUB      24
    JUMPN    v
    COPYFROM 22
    OUTBOX  
    COPYFROM 21
    OUTBOX  
    JUMP     l
v:
    COPYFROM 23
    OUTBOX  
    COPYFROM 23
    ADD      21
    OUTBOX  
    JUMP     k
w:
    COPYFROM 20
    ADD      23
    OUTBOX  
    JUMP     j
x:
    ADD      24
    JUMPN    aa
    COPYFROM 23
    OUTBOX  
y:
    COPYFROM 23
    OUTBOX  
z:
    COPYFROM 22
    OUTBOX  
    JUMP     c
aa:
    COPYFROM 20
    OUTBOX  
    JUMP     i
ab:
    ADD      21
    JUMPN    af
    SUB      22
    JUMPN    ac
    SUB      24
    JUMPN    r
    COPYFROM 23
    OUTBOX  
    COPYFROM 21
    OUTBOX  
    JUMP     h
ac:
    ADD      24
    JUMPN    ae
    COPYFROM 23
    OUTBOX  
ad:
    COPYFROM 23
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    JUMP     d
ae:
    ADD      24
    JUMPN    y
    COPYFROM 21
    ADD      23
    OUTBOX  
    JUMP     f
af:
    ADD      22
    JUMPN    ag
    SUB      24
    JUMPN    z
    SUB      24
    JUMPN    ad
    COPYFROM 21
    OUTBOX  
    JUMP     e
ag:
    ADD      22
    OUTBOX  
    JUMP     b


DEFINE LABEL 20
eJzjYGBgMEp/bWCUfjBvd/K5y0Auw5uG1wYZTVtSM5p2HmEgElzrqDtxrrvskEff8+1H+gOWu/Zbz3jY
0l+R0cRRUlzHUshSwVJIrFmjYBSMAvoBAG1NHvg;

DEFINE LABEL 21
eJwTYmBg0JqZqa87I9eIpSLXiL8kU39C8XvjCcXXav9XepdlNx4tdJjoXLBz8smSbVOu1W6b0jR3zyTZ
jUf61+wO6tp5JKF17/GphfYnGUbBKBgFQxIAAGlqIpc;

DEFINE LABEL 22
eJwTZ2Bg2JxWaGqU/tpAK+u5LmNlpv7P6lyj500MDhEds4MjOtSiY9vM0t80nCv/UxXT9KbhXnNyy+ue
ax0Mc0I7p6+J6FDacqdtxY7nTUYHqqv3Hl+WbX/yQOLOIyfithxkGAWjYBQMegAADh4tmg;

DEFINE LABEL 23
eJwTZGBg2JB+L3R15iWfZdneHr0le22rq/fa5jacdHvZeMknuaU0LbVZtLag3nne/8rXuxgr/xz7X8lw
6mUjy9nQTpaza2Z0X2QYBaNgFAxZAAAROCHS;

DEFINE LABEL 24
eJxjY2BgqK7eYPKxLiIwu7Gr9Emz95Lklum3GJDA5Nbbpgc6pznp9xj6/ug7mvGjj3eRZJfNCde2HRcm
1ZreZKwwvZlfxHbNL3/leZ2cf4e5Mnes5cosnL4nc0bHiSyrJpAZX/Kur9/SYFRwoHNtKMMoGAWjYNAA
AK/vMXQ;

