-- HUMAN RESOURCE MACHINE PROGRAM --
-- 39-Re-Coordinator - SIZE 35/14 - SPEED 44/76 --

    INBOX   
a:
b:
c:
d:
    SUB      15
    JUMPN    g
    SUB      15
    JUMPN    f
    SUB      15
    JUMPN    e
    COMMENT  0
    OUTBOX  
    BUMPDN   15
    OUTBOX  
    BUMPUP   15
    INBOX   
    JUMP     b
e:
    COMMENT  1
    ADD      15
    OUTBOX  
    BUMPUP   14
    BUMPUP   14
    OUTBOX  
    BUMPDN   14
    BUMPDN   14
    INBOX   
    JUMP     a
f:
    COMMENT  2
    ADD      15
    OUTBOX  
    BUMPUP   14
    OUTBOX  
    BUMPDN   14
    INBOX   
    JUMP     c
g:
    COMMENT  3
    ADD      15
    OUTBOX  
    COPYFROM 14
    OUTBOX  
    INBOX   
    JUMP     d


DEFINE COMMENT 0
eJwTZGBg2FZ83vFeuaetVF2iTVHzPOd3LXe8rFoZgxe1zA+bVv8yrazCuFyszLh8WaVxeVDNpSqnpq4J
cY0/pt4rT1tXlbtkK8MoGAWjYMgCABLiHv8;

DEFINE COMMENT 1
eJzjZ2BguJX/3OFZiaetUKOBXVHzPGer1jtedR1H4sQ6j7UYdbzu4WpZP+Na1YOVz0oerPxVtn51VI/f
+kXT/dYzjIJRMAqGPAAA6tAd0g;

DEFINE COMMENT 2
eJzjZWBguFSkFn2oYkforabtTvuabd2tWguy21pl5oW1OO10agq4ClTCkFVsfq2riv3Grr6TFxhGwSgY
BcMGAAACbBX/;

DEFINE COMMENT 3
eJwTZWBgmFb/xXNZ5YvgdWVfY/xKLqYvKmSq3FeQ2sFVKDMvq7h+rVgZ66agmj1b2lr3bDHquLL5XpfZ
hl19lxfM6/8xla0/taOsOzzHr/1rjFNTe/i1KsZghlEwCkbBkAEA/98oyg;

DEFINE LABEL 14
eJwTY2BgOF722Syw+Lvl0+w+L51MyaAP6UsijdI3JL3NEKzKzHrcppKT29dabj3DsqZu1svGvTPnt1ZN
n95ROJGvZ36Lb49g1cWuNfH3WrvcF7W4uxbUszhbV/+xYRgFo2AUDAkAAJ/ZKII;

DEFINE LABEL 15
eJyTYmBgyMuYrVqYnqBpkrbBpCUhxE8oekvqg1Ce8tSQ2Y3rA3L7PvtZz/jsd3DO+oCj85eEHJ1vkvZj
qnNF4USgVoavqY+0tqU+1y1M5/HckO5evDpTsW1F1s5pWlkhq1Zk9V9ZnSl7/1Vm5nOGUTAKRsGgBAAX
ji7h;

