-- HUMAN RESOURCE MACHINE PROGRAM --
-- 19-Countdown - SIZE 90/10 - SPEED 64/82 --

-- This solution is level-specific (quality-limited input) and assumes inbox
-- items with value of no less than -9 or greater than 9.

    INBOX   
    JUMPN    u
    JUMPZ    a
    COPYTO   0
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
u:
    COPYTO   0
    OUTBOX  
    BUMPUP   0
    JUMPZ    a
    OUTBOX  
    BUMPUP   0
    JUMPZ    a
    OUTBOX  
    BUMPUP   0
    JUMPZ    a
    OUTBOX  
    BUMPUP   0
    JUMPZ    a
    OUTBOX  
    BUMPUP   0
    JUMPZ    a
    OUTBOX  
    BUMPUP   0
    JUMPZ    a
    OUTBOX  
    BUMPUP   0
    JUMPZ    a
    OUTBOX  
    BUMPUP   0
    JUMPZ    a
    OUTBOX  
    BUMPUP   0
a:
    OUTBOX  
    INBOX   
    JUMPN    u
    JUMPZ    a
    COPYTO   0
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
    OUTBOX  
    BUMPDN   0
    JUMPZ    a
