-- HUMAN RESOURCE MACHINE PROGRAM --
-- 06-Rainy-Summer - SIZE 22/6 - SPEED 20/24 --

-- Based on 26.20.unroll-mrflip.asm

    INBOX   
a:
    COPYTO   0
    INBOX   
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    INBOX   
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    INBOX   
    ADD      0
    OUTBOX  
    INBOX   
    COPYTO   0
    INBOX   
    ADD      0
    OUTBOX  
    INBOX   
    JUMP     a


