-- HUMAN RESOURCE MACHINE PROGRAM --
-- 25-Cumulative-Countdown - SIZE 11/12 - SPEED 82/82 --

-- This solution is superseded by 11.79-skwasjer.asm being functionally same
-- with further optimization.

a:
    INBOX   
    JUMPZ    d
    COPYTO   1
b:
    COPYTO   0
    BUMPDN   1
    JUMPZ    c
    ADD      0
    JUMP     b
c:
    COPYFROM 0
d:
    OUTBOX  
    JUMP     a


DEFINE LABEL 0
eJxLYGBg2CyvFl2s0h5+Wa09vF5TLdpezz53vsHOammj1I7zhtNmKut3LdbW+bGiXvPEqnDVByu/K0Ut
dVY+Pr1YJXJStvrUtsfGR+LiTdWiZ1vnRwCNY9juu7ZofUBK6aNI77KwOL78rIQFmUZJdlHPEhmD2+JV
PW7FtLl0h7S51Puv9gn35o357rG26LuH4+Ttvizzd4V2LT4W1bW4LmnaTJBZWW2TfdtaVT3UmvNcg2ra
XLqqQt2iKr94JpWtif9VtiCTr/Jb/qualFKr1pTSdy3qjX1NGlM21aXNVqqWmcdUIjNvUeH6GW1FGlNA
ZoVN9wpQm3a34NuUS1XfprzuKZo2babVDJb5WTMvL1g6/838ymX3p91csai/dbV6Y+aauwWZa/IjLq7e
Edq6OqJedg1zz9O1P6aKrr8/zXazwNTOzYUTQWbePRwvdvfw/WmlR+pmLT2aNtvxXNpskPjKByuEHR9G
Trr5UGBqyGOBqSIvZLojXvt0guQCb7eHr3xgGDjn3WFvhlEwCgYYAABa86zc;

DEFINE LABEL 1
eJxjZ2Bg+FT53AFIMRyqSCktq1iyNarSaeenSv9DDKNgFIyCYQ8AcC4LPg;

