-- HUMAN RESOURCE MACHINE PROGRAM --
-- 29-Storage-Floor - SIZE 21/5 - SPEED 21/25 --

-- Cheap tweak of @AlanDeSmet's solution: adding a jump makes it not input-specific

a:
    COMMENT  0
    INBOX
    COPYTO   10
    COPYFROM [10]
    OUTBOX
    INBOX
    COPYTO   10
    COPYFROM [10]
    OUTBOX
    INBOX
    COPYTO   10
    COPYFROM [10]
    OUTBOX
    INBOX
    COPYTO   10
    COPYFROM [10]
    OUTBOX
    INBOX
    COPYTO   10
    COPYFROM [10]
    OUTBOX
    JUMP     a

DEFINE COMMENT 0
eJzzYGBgeMN1UChW4A9fi6QVn6k8g1CIdoQyv66i1lldBofJ2hGBszXWxL9Qrsp0l6jK7Bc1S78o8jml
X3RN/GHJ1KjN8ksi3Qzsc4HGMLh6iCp2uYkq9rvcUrnuaGQm6TjZd6qTWnS/i1m6qwdDXpVPU/5Gf/tc
7aDv6cqhK2Liw6YHzAuztlEOVdPVCL6m+NG/S9LW+6REvRePNMg8+blnpfsW80gfXXZJ7u/KTH2bVdY2
/1cEeLsvWxFzdnFh8o351lkL59TlpM/am/16hlGKxqzchKsLlkR2Ll0SuWHdhiSQGXsOCsqx7L8k17Vn
tmrv7tcGZ3afdGvavyRy++EtqQpnmvInXqzLcb9amHzw+q0ghht1dl5X7qmLXjgrveRUk/DHo3UCDKNg
FAxzAABBuHRe;

DEFINE LABEL 10
eJzTZGBgyAp63LYm8Pn29QEcF0r93r8u9fvxsdy36vNOnxXPdvqUHfrsl9mdH3CrYUkIR8nE6LqcY/HW
WU6J1lnbUjlKjNIj6o3Sn3dWpuycZpO8d+accNHVqiERa4HGMjRXHHSYXNRfIVlwchGI/yLrXihLxa2g
Nw0hftLtIX4gsWsdkg1XOp93Xus4uWh6x85pF7vuNbf3HczbN9Eo5dsUvUTV2X+yGEbBKBgFNAMAfANM
sQ;
