-- HUMAN RESOURCE MACHINE PROGRAM --
-- 35-Duplicate-Removal - SIZE 16/17 - SPEED 157/167 --

    INBOX   
    COPYTO   [14]
a:
    COPYFROM [14]
    OUTBOX  
    BUMPUP   14
b:
    COPYFROM 14
    COPYTO   13
    BUMPDN   13
    INBOX   
    COPYTO   [14]
c:
    SUB      [13]
    JUMPZ    b
    BUMPDN   13
    JUMPN    a
    COPYFROM [14]
    JUMP     c


DEFINE LABEL 13
eJxjZWBgEOtsyhfuirgNZDJEtesZM2AB8+14PBfZXvPXs0wIbzZUi76gsyQSJN4T+93ydeC9UFM/vcQ9
3va5tt7nyn/6yDY/C/4x9Voky3zWhK7FX1NPLlLPtp8dnb9hwuSi2Y38JSyFgsVLIsULbwUtyL3ko5XF
41mY7u3xNfWsJ8hM+bkszjkzTrq1980O5u59FOHVqxXn2l+YvGfSzoyYeTzlgYtkmwMXbZgwc7797MQ5
bQt0Z5xcZDX55CK2/qPzBbqtZ2Bz/ygYBaMAOwAA3NBOcw;

DEFINE LABEL 14
eJzjYWBguNYh6DO9Y0vqlc5LKyQ6NuyLbftxeGnz3uOb6v4cc64oO/Q0e8lWoDIGiY46AQY0sLzJLB1E
F9S3ufT0NDmC2PFzz3rKzpsdLDtvZ8bCOXr9IDH+xYI+nktToyxXnyx5tUGrJ2HLzmlzt5ZOubUttUNy
e3+F5PbStLlbIfoJgaTTs4PnnI1YC2LrHZ+uRIyeUTAKRgF2AACsWz4M;

