-- HUMAN RESOURCE MACHINE PROGRAM --
-- 40-Prime-Factory - SIZE 28/28 - SPEED 247/399 --
-- HUMAN RESOURCE MACHINE PROGRAM --

a:
b:
    INBOX
    COPYTO   10
    COPYFROM 24
    COPYTO   22
    BUMPUP   22
    COPYTO   1
c:
    BUMPUP   1
d:
    COPYFROM 24
    COPYTO   12
    SUB      10
e:
    COPYTO   11
    BUMPUP   12
    COPYFROM 11
    ADD      1
    JUMPN    e
    JUMPZ    f
    BUMPDN   22
    JUMPZ    c
    COPYFROM 10
    OUTBOX
    JUMP     b
f:
    COPYFROM 1
    OUTBOX
    BUMPDN   12
    JUMPZ    a
    BUMPUP   12
    COPYTO   10
    JUMP     d


DEFINE LABEL 1
eJwTYGBgWNvAIGRdXScQWHxUVLzwpMTcvBCFuLzF2rPzRf1n529Jlc973x+XJ7sRqJTBKP17+qGKP1kg
tnZj2x+GUTAKRsGQBgAdUBav;

DEFINE LABEL 10
eJwTZmBgULQ76vzEpq1oke2lFSq2ojeBQgwRjgcdhJ0POgS4sDifcc1NcPa8Vvvbu2vxRv/cPWsC3c+D
1CiE7bB6HJIZuySk7NCzYKN3DKNgFIyCIQcARSQdYQ;

DEFINE LABEL 11
eJwTZGBg+OyX22fsb3Rgi9/Rs0Aug3aQ87yVQXWzbkRkdgtFr+g6HcuxiDXB+hhIriZZiwlEn47deeRE
nPUxjviTFxhGwSgYBUMWAABzARiZ;

DEFINE LABEL 12
eJyTYGBgMEp/3VOWuqTdPX5J++UorZ7b4aVT7oXZz74XdnS+bLjPEqmIgOX+MRFrj8VLrjuQeG01A1iP
Xr9J2s5p21I5Fn1K4738IX3Bg3UZSx6vzlR7ujhH9j5IzddUPVaGUTAKRsGgBgCj+io2;

DEFINE LABEL 22
eJwLY2BgiG17zQSkGHpinQsuR614BmK3xR/Mq0uyzsrM+p6ekmOdFZ1/skS8cHbj1MINE8QLrWck5gYs
B6k7kOiz5Ffy5JUb0qevUcm5thokNqVzS6pc2/tE5ZbC5DcNdTlfamOavtQaTdJraFuQ2hywXKzz0oqT
vV2LQWoZJqpFO0w8t7R+4qUVFlMmrwQJBXR/Tz/WZ53VNIEhD8S3XF2aVr1qQ1LjitwE/sV6iVLzqzLj
53aV3p07u3Hm/CXtExet6WVaYTQJpPbBnHNL786dvubqAtmNrMsfb9m7MnHz1zWS6wzXBSwvXMexCKTG
ZtWGCV/XmE0tXms9A8SvOvQ6rvZgZqzH3sxYv925CTO2V2XO2tZWNGubYJXIzpgmv93zW+wOzm/ZdUit
c/thvf7SIxyLvh2evPLPQcl1IP1yW0NWzdoWs+H8riVb3fapbW84sGQrwygYBUMEAAAk8ZrZ;

DEFINE LABEL 24
eJzzYGBg+GI2uXqFdUT9GdeYpibP2Y2PbK+t3mp29CxQiuGV1ckL0g5Hz+73cj7z0b/t3PqA7osg8YnR
R+d7xZ1cVJh+ctGCXI5F1wtY5gcW/5nBX/J5En9JZvelItnm1ZmitfZJITVOiddq2+JjmqZEHZxzLTJm
w5SoNbsvRP84fCLO/uSOFOczMvlHz54taToNMnd9PU/52oYfh7Mb+6+A+M+bGOaoNf+Y+rDleadEh2TD
xS7R2j2TRGurJkfUg+RPLL3V0Ld4duPM+akdC+e8738xk2HO6xnT1zybVbhffq79yfAFPpdOLwm4yrTi
3OX/KyBud18m21y3UrZ589rHbW/XF07U3Ni1WHNj5s61693Pb1jHe/nXqms3QeoWbXYWYRgFo2CYAwCS
zo0H;

