-- HUMAN RESOURCE MACHINE PROGRAM --
-- 03-Copy-Floor - SIZE 6/6 - SPEED 6/6 --

-- The copyfrom command is introduced. Copy the letters B U G to the outbox.

    COPYFROM 4
    OUTBOX  
    COPYFROM 0
    OUTBOX  
    COPYFROM 3
    OUTBOX  

