-- HUMAN RESOURCE MACHINE PROGRAM --
-- 23-The-Littlest-Number - SIZE 58/13 - SPEED 29/75 --

-- This solution is level-specific (patterned and quantity-limited input).
-- Based on 63.29.specific-viamodulo.asm

    INBOX   
    INBOX   
    INBOX   
    OUTBOX  
    INBOX   
    INBOX   
    INBOX   
    INBOX   
    INBOX   
    OUTBOX  
    INBOX   
    INBOX   
    COPYTO   0
    INBOX   
    SUB      0
    JUMPN    a
    INBOX   
    SUB      0
    JUMPN    c
    INBOX   
    SUB      0
    JUMPN    f
    INBOX   
    SUB      0
    JUMPN    j
    COPYFROM 0
    JUMP     m
a:
    ADD      0
    COPYTO   0
    INBOX   
    SUB      0
    JUMPN    b
    INBOX   
    SUB      0
    JUMPN    e
    INBOX   
    SUB      0
    JUMPN    i
    COPYFROM 0
    JUMP     l
b:
c:
    ADD      0
    COPYTO   0
    INBOX   
    SUB      0
    JUMPN    d
    INBOX   
    SUB      0
    JUMPN    h
    COPYFROM 0
    JUMP     k
d:
e:
f:
    ADD      0
    COPYTO   0
    INBOX   
    SUB      0
    JUMPN    g
    INBOX   
g:
h:
i:
j:
    ADD      0
k:
l:
m:
    OUTBOX  


