-- HUMAN RESOURCE MACHINE PROGRAM --
-- 39-Re-Coordinator - SIZE 14/14 - SPEED 73/76 --

    JUMP     b
    COMMENT  2
a:
    ADD      15
    OUTBOX  
    COPYFROM 1
    OUTBOX  
    COMMENT  1
b:
    COPYFROM 14
    COPYTO   1
    INBOX   
    COMMENT  0
c:
    SUB      15
    JUMPN    a
    COPYTO   0
    BUMPUP   1
    COPYFROM 0
    JUMP     c


DEFINE COMMENT 0
eJxzYGBg2CnL4vxDNiHcVkav31YmYHmNjNauSlnrY6byTaeNFFjOvlaqO8FiKNlgZlaV+dxaMWKufUTg
dcdr/lOdYkKuOL2OE3M6mJdg92PqHfvSKR7uEfX5AVpxqSGzg29EhPiJRsmGTok6WhgSNbtxZkTTXKB1
DLfyX8c9zU4IN0qXDd2c9nmSUXr/Mp3MFTuWZX8+IJ9Xdki88POB5grJdfNbY5pSm2M2KLdk7lRo1doF
0lu3UrDKfuX8TTaruhaD+NkbdvCA6K49XaUee2c3euzdO/PjUeeCZyc3JM05mxolfFExgvfyo4iTVzJj
Xa+VpjVe5yixv7Gkfd+Nprn2Nwr3M4yCUTDCAQBDvG6a;

DEFINE COMMENT 1
eJxzY2BgWGuZGtVm8D3dU98+l92Ao8TR6FKVpvX7/ic2dbOW2jTNtTERXAFUxpAeHFF/LTKiniFJsGpF
FkNeSk5V5qOczykqObkJeRnPo3+kqEUzJb6Oux3eVZofUDhxo3/dLIOArsUrg66tvhd2a93pWMl1IHPm
tM0OjpkXEwJiL5u1wWTNDA63gxN4yo/1qXV69fYv8+ibvgYkV73KOqt61Y+plqsZ5mxYx7t09Qbepcmb
ORZd2mk0qeFAW1HtwQ0Tag/eApvZeJ2j5OD1x23M13dO87qitv3ixZ1HJM63nZM9239F4YzPpXtnGE5N
P6+1y/6G2dTPd5a0r3wg2aD0eHrd3SfXamOe3mue92RJ+4LHK7oyH6zpXXevcCLDKBgFIwQAAEbfhMk;

DEFINE COMMENT 2
eJwzZGBg6HWdHtDl9jz6pNufrF7Xa7XnXboWf/YTrEoK3ZJ6LiYh/Ffy9ICwwmv+3aWzg0+VPo8GamGQ
aztXfnduf4XQoq5S9mX2uUwrjFIcV6RGuSyf7Ht6CYfbxEVHnVVnSwbx9XiXxbat6Fre1DT3ZeP0NUub
l2y907Zmd1dv4f7PUzfsA5m16xCHW+mRyb4FxyICl5+cHdx4PSHc/LZsKEhO+OJs1csXvlvOOfs+8eWJ
9/16x0VXrz/2fm/uceczy0+euzz/jOA1hlEwCkYB2QAA+UpfuQ;

DEFINE LABEL 0
eJyzZ2BgaDZ0d20zOOsZqCPbfEuj7JCItujqQ4bT68zMvqdnWz2KmG93zV/Qhcfzm+9Jt9eBZz2XhIT4
PQidHfwgVC0aqJ0hLTumSbnlVkNER0iNcFdX6aQu+1yxTr1EubbZwasau9y319TZ/a+0tw8sTgh/lXmv
+Wsqw5zdyZLrbJLf792RYn/SKL3tnHq2+/mrhW3nDlXYnwSZGTlfK058wZ+smfNXdC2ePX/TuulHz/Yt
PlnSvFwt2nyNoM+GdWc9Mzee9Vy0ebLv3K0J4bO2bUmN3natNmHLlsmaGwOWz91aN+vb4S2pb44/j1Y+
vSRS9qxWnPS5uhzpczFN8WcOznlzfMUOhlEwCkYBAwBnS3fJ;

DEFINE LABEL 1
eJzTZWBgkIjcmfE68E/WHu9z5V1uj9smOW+ZPN3RfWG0w+z1sxyMDog5OZ8RdDl3uctN9Caz57WbVT6T
r+cGup9XCNtycGK05Drz1Ij6dRmFyasz+710Mo3MCtMlVXakvO/fnXzuMtB4hvmtglWLWnZOe1/fds6w
XvLO+nrRmyDxax3OIiDaaJp78esZS9pnz/txmH9xxG3PpbL3WZffulO3UvDa842vd/08xFGy6kRuguzZ
+WH9l0T9GUbBKBgFVAMATANS9w;

DEFINE LABEL 14
eJyzYmBgkNHINbqgs8W82NzaZoU1g8NUJ0EfQZdbQQEujyKCnbXiZjkYpayw3pttY+JdJq+e0PpWMbdv
s7z1jHWKdbPm2rsvBBrBcC6GIe9XslacVcqSyN3JsqHu8Zd8hKLPes4LE/R5GTQ7uMi/NO2nT0jNHu8t
k2u9RVdX+azY8dlPb+/LoPd7Y8JX7ACZIVLE4ACig4vaXCYXrYgRKdqZsSBXse1RjtEkx0qz9OI6xYjk
FkGfKZ3eHl293h71E0P8QOo9l3K43Z37PnHlzP6K35O6FttOkly3ZWrIqvRZB+fcmJ/Z3bhiZwbDKBgF
owArAAAlCl0r;

DEFINE LABEL 15
eJyzZ2Bg0LOUVGEyilE7pbdYO1DnvfEMzSbHBWoxIctUtqTqKr3u2ajQdHqb3LnLQKUMosK5fedES6cc
lrSeUSJfNytRzX72Kb0/MypMS6eA5FdnepeZpDXl/02yzz0Wz5DnE9tWJBQ9uVohrG7W45Bb6xaG3ts4
M0J2o3kqy/xl2Xr9C3IV2+bmXasF6TWsv9VQUK+3N7dh55GMJoZTyi0Mp2a17zyyc3LIqtczfkxNmX2r
YfHsc+Wqsz9PWjx7yValOZk7wfrWWWeB6MJ1f7I2rJvdaLiuavqGdXWzHm3O7GbbZ5RSe/B5tPHRhPBV
J+6FPjydEH7z3PNoryt7sxlGwSgYBQwApxJwQA;

