-- HUMAN RESOURCE MACHINE PROGRAM --
-- 07-Zero-Exterminator - SIZE 10/4 - SPEED 19/23 --

-- This solution is non-input specific

a:
b:
c:
d:
    INBOX   
    JUMPZ    a
    OUTBOX  
    INBOX   
    JUMPZ    b
    OUTBOX  
    INBOX   
    JUMPZ    c
    OUTBOX  
    JUMP     d

