-- HUMAN RESOURCE MACHINE PROGRAM --
-- 25-Cumulative-Countdown - SIZE 117/12 - SPEED 39/82 --

-- This solution is level-specific (patterned and quantity-limited input).


    BUMPUP   5
    BUMPUP   5
    ADD      5
    COPYTO   4
    INBOX   
    SUB      4
    JUMPN    a
    COPYFROM 4
    ADD      4
    ADD      5
    JUMP     b
a:
    COPYFROM 4
    ADD      5
b:
    OUTBOX  
    BUMPUP   4
    INBOX   
    COPYTO   0
    SUB      4
    JUMPN    c
    JUMPZ    g
    SUB      5
    JUMPZ    i
    JUMPN    h
    SUB      5
    JUMPZ    k
    JUMPN    j
c:
    ADD      5
    JUMPZ    f
    JUMPN    d
    COMMENT  6
    BUMPUP   0
    ADD      0
    JUMP     p
d:
    ADD      5
    JUMPZ    e
    COMMENT  4
    BUMPUP   0
    JUMP     n
e:
    COMMENT  3
    COPYFROM 0
    JUMP     l
    COMMENT  5
f:
    COPYFROM 0
    ADD      0
    JUMP     o
g:
    COMMENT  1
    COPYFROM 0
    ADD      0
    ADD      0
    JUMP     q
h:
    COMMENT  2
    BUMPUP   0
    ADD      0
    ADD      0
    JUMP     r
i:
    COMMENT  0
    COPYFROM 0
    ADD      0
    ADD      0
    ADD      0
    JUMP     s
j:
    COMMENT  7
    BUMPUP   0
    ADD      0
    ADD      0
    ADD      0
    JUMP     t
k:
    COMMENT  8
    COPYFROM 0
    ADD      0
    ADD      0
    ADD      0
    ADD      0
l:
m:
n:
o:
p:
q:
r:
s:
t:
    OUTBOX  
    INBOX   
    OUTBOX  
    INBOX   
    COPYTO   0
    SUB      4
    JUMPN    u
    JUMPZ    y
    SUB      5
    JUMPZ    aa
    JUMPN    z
    SUB      5
    JUMPZ    ac
    JUMPN    ab
u:
    ADD      5
    JUMPZ    x
    JUMPN    v
    BUMPUP   0
    ADD      0
    JUMP     af
v:
    ADD      5
    JUMPZ    w
    BUMPUP   0
    JUMP     ad
w:
    COPYFROM 0
    JUMP     m
x:
    COPYFROM 0
    ADD      0
    JUMP     ae
y:
    COPYFROM 0
    ADD      0
    ADD      0
    JUMP     ag
z:
    BUMPUP   0
    ADD      0
    ADD      0
    JUMP     ah
aa:
    COPYFROM 0
    ADD      0
    ADD      0
    ADD      0
    JUMP     ai
ab:
    BUMPUP   0
    ADD      0
    ADD      0
    ADD      0
    JUMP     aj
ac:
    COPYFROM 0
    ADD      0
    ADD      0
    ADD      0
    ADD      0
ad:
ae:
af:
ag:
ah:
ai:
aj:
    OUTBOX  


DEFINE COMMENT 0
eJwTZWBgaM5ZI5VdWqrY2lyqyNj6R3VWOwgnaD5p9jb0blR03FT3KGJu1euehso1S56X7T0O1MIQmXK0
8FLR0cK5VVqlcm1apU0TjhZKT7bPnT7FPpdhFIyCUTBkAAB4biSE;

DEFINE COMMENT 1
eJyTZWBgiK6+ZBpdbWZ5v1LR8X4lj+ehiu8Bhyo4Sn62c5Tw9Xyu/jbFekb/9K7FB+aYHz4wZ8X5m5N/
3HKY+PhRaWfI+y+1Ie+jq9+/vl+Z+fx+JcsToHEMf6oumVbUXDI93jTb5mf7bJubky+Zcs98rmszL0GT
fdkfVYZRMApGwaABANQ8O2c;

DEFINE COMMENT 2
eJyTYmBgqKh5rnuowsxSs6zN5XuBUUpcnmzO0eyqhqPZARMe5VjPqM5XW7C2RHBFckXiZr2GS/vvtF3a
P6nr+fYj/YIrjvQHTPjYVdVQ2lnVsL9Vq1SteUmBYL197v1K+1y38p0Z1fkgLJvDMApGwSgYlAAASH8x
Lw;

DEFINE COMMENT 3
eJzjZWBguBC9wrUuydvQJC1B81GOmtj/XBCeL1idP1/wUY6i46McoxTPrNQOzyzzw2nZ5ocZRsEoGAXD
BgAADLgUOQ;

DEFINE COMMENT 4
eJyTYGBgqEt6FDE7+VGEeGpd6Ib0yb5nM1a4ri3xNjxV+lzXrRyEvQ3vVyo6Tq1dUjC1tqohuvpe8/3K
k91u5VsmV+ebH36Us+K8Z9bk60D990/Ehbw/mxHy/n9u5vPSzsznDKNgFIyCQQ0AswAwKg;

DEFINE COMMENT 5
eJxTYmBgeBqv6LghPUHTsDhB837lBpOKGkVHwXoeT8H6swkVNbI59ytlcyYUf66uzq9qmJxW1XCqtKrh
fuW95oqa1A7B+oAJqxq3TF7VaD3jZ3vp6kldPrsndf24FdHx+NH+1seP1Jozn/c2ZD6vqGF5IlLE8qQ6
v+7+0ey6+zqZk69vSAdhvSszCiZfZxgFo2AUDAgAAHT8RAE;

DEFINE COMMENT 6
eJyTYmBgeBp/yfRE3CVT/ZjZNtMi21xeBp1NCAgwSjH2l83Z7iubI+fNUXLFr79iXtjn6qfx95pnFNxr
Tq6oaphaC8KitRU1orWaZUsKgEYxgMx5Gv8oYkP68+2eWUqn07JXnH+Us+I8wygYBaNgUAIAWNIvLQ;

DEFINE COMMENT 7
eJzTYmBgUGs+qiNYX6pYUSMop1lmxVedb8W3If2WyuS0ozriqbNtxFPdY0zSdmaczZDNeZTTX1Gd/7n6
VGnAhIqa+bNXNZauTmj12V3aufd4aefk6xEdP265lf+4tbZE74pIEQivOF+dv+L8o5y9x3UyI45MTru0
/1fy8+2JiYIrZidfmyKeGjDBJC21Y0N6asejHNHa+5V1oX+qJvv+qVJ0FKx/rqvX8Fx3VWOCJsMoGAWj
gCYAABCgT5s;

DEFINE COMMENT 8
eJyTZGBgcCt3j/lTxeP5p8rM8n6lt+HakgRNz6wEzV/J3oYn4jaYbI4ys5SKUHT8G8bj+TfsUcSF6J0Z
mXGyOUyJHCVp2RwlMwrsc0+VZsaeKq0LnVCc2iFSZD2jOl9wRVze8+1xeeaHGUbBKBgFgxYAAD+YKPs;

