-- HUMAN RESOURCE MACHINE PROGRAM --
-- 32-Inventory-Report - SIZE 194/16 - SPEED 23/393 --

-- This solution assumes a fixed set of tiles with counts A=3, B=5, C=2, and X-3,
-- and that each of A, B, C, and X will occur in the input once and only once.

    BUMPUP   14
    INBOX   
    SUB      4
    JUMPN    l
    JUMPZ    f
    BUMPUP   14
    COPYTO   19
    BUMPUP   14
    OUTBOX  
    INBOX   
    SUB      3
    JUMPN    d
    JUMPZ    b
    COPYFROM 19
    OUTBOX  
    INBOX   
    SUB      3
    JUMPN    a
    BUMPUP   14
    BUMPUP   14
    OUTBOX  
    BUMPDN   14
    JUMP     aa
a:
    BUMPUP   14
    OUTBOX  
    BUMPUP   14
    JUMP     ab
b:
    BUMPUP   14
    BUMPUP   14
    OUTBOX  
    INBOX   
    SUB      4
    JUMPN    c
    COPYFROM 19
    OUTBOX  
    BUMPDN   14
    JUMP     ac
c:
    BUMPDN   14
    OUTBOX  
    COPYFROM 19
    JUMP     ad
d:
    BUMPUP   14
    OUTBOX  
    INBOX   
    SUB      3
    JUMPZ    e
    COPYFROM 19
    OUTBOX  
    BUMPUP   14
    JUMP     ae
e:
    BUMPUP   14
    OUTBOX  
    COPYFROM 19
    JUMP     af
f:
    BUMPUP   14
    OUTBOX  
    INBOX   
    SUB      3
    JUMPN    j
    JUMPZ    h
    BUMPUP   14
    OUTBOX  
    INBOX   
    SUB      3
    JUMPN    g
    BUMPUP   14
    BUMPUP   14
    OUTBOX  
    BUMPDN   14
    JUMP     ag
g:
    BUMPUP   14
    OUTBOX  
    BUMPUP   14
    JUMP     ah
h:
    BUMPUP   14
    BUMPUP   14
    BUMPUP   14
    OUTBOX  
    INBOX   
    SUB      1
    JUMPZ    i
    BUMPDN   14
    BUMPDN   14
    OUTBOX  
    BUMPUP   14
    JUMP     ai
i:
    BUMPDN   14
    OUTBOX  
    BUMPDN   14
    JUMP     aj
j:
    BUMPUP   14
    COPYTO   18
    BUMPUP   14
    OUTBOX  
    INBOX   
    SUB      3
    JUMPZ    k
    COPYFROM 18
    OUTBOX  
    BUMPUP   14
    JUMP     ak
k:
    BUMPUP   14
    OUTBOX  
    COPYFROM 18
    JUMP     al
l:
    ADD      14
    JUMPN    q
    BUMPUP   14
    COPYTO   19
    BUMPUP   14
    BUMPUP   14
    BUMPUP   14
    OUTBOX  
    INBOX   
    SUB      4
    JUMPN    p
    JUMPZ    n
    BUMPUP   19
    OUTBOX  
    INBOX   
    SUB      1
    JUMPZ    m
    BUMPDN   19
    OUTBOX  
    BUMPDN   14
    JUMP     am
m:
    BUMPDN   14
    OUTBOX  
    BUMPDN   19
    JUMP     an
n:
    COPYFROM 19
    OUTBOX  
    INBOX   
    SUB      1
    JUMPZ    o
    BUMPUP   19
    JUMP     z
o:
    BUMPDN   14
    JUMP     y
p:
    BUMPDN   14
    OUTBOX  
    INBOX   
    SUB      4
    JUMPZ    w
    BUMPDN   14
    OUTBOX  
    BUMPDN   14
    JUMP     ao
q:
    BUMPUP   14
    COPYTO   19
    BUMPUP   14
    BUMPUP   14
    OUTBOX  
    INBOX   
    SUB      4
    JUMPN    u
    JUMPZ    s
    BUMPUP   19
    OUTBOX  
    INBOX   
    SUB      3
    JUMPZ    r
    BUMPDN   19
    OUTBOX  
    BUMPUP   14
    JUMP     ap
r:
    BUMPUP   14
    OUTBOX  
    BUMPDN   19
    JUMP     aq
s:
    COPYFROM 19
    OUTBOX  
    INBOX   
    SUB      3
    JUMPZ    t
    BUMPUP   19
    OUTBOX  
    BUMPUP   14
    JUMP     ar
t:
    BUMPUP   14
    JUMP     x
u:
    BUMPUP   14
    OUTBOX  
    INBOX   
    SUB      4
    JUMPZ    v
    BUMPUP   19
    OUTBOX  
    BUMPDN   19
    JUMP     as
v:
w:
    COPYFROM 19
x:
y:
z:
    OUTBOX  
    BUMPUP   19
aa:
ab:
ac:
ad:
ae:
af:
ag:
ah:
ai:
aj:
ak:
al:
am:
an:
ao:
ap:
aq:
ar:
as:
    OUTBOX  


DEFINE LABEL 1
eJzjYWBgMI9UdIwJ/5PlETx/tnaQ/SagEENM+GTfGxExIZEpRitB/MbQgAk3Inj7GEbBKBgFwwoAAGHT
Duc;

DEFINE LABEL 2
eJzjYmBgsG7f4ufcsib+ednBOVsLp68BCjE052TGzq2613y+/nXPohbrGQyjYBSMgmEJAIITEa8;

DEFINE LABEL 3
eJwTZWBgsCy4lTmjYPqasELZjUAug0qOe4xj7vywS0UB3lNrA7yD6yb7CtbXhQbXrYm3q/qTdb+yKV+v
waxuUcvkST/bEzc7tyzZald1dNunNBD+s55hFIyCUTBkAACOpCYF;

DEFINE LABEL 4
eJwTYGBgONK/xe9lb4D39o7X7noNJ93+VOl5aZZ9D1hb8ihCpGh2Y1ih5PSwQp/dl4qUTmeXWt+1q3J/
1tr8+NH2jph7DKNgFIyCIQ0AoykfDw;

DEFINE LABEL 14
eJxjYWBgKC5ydiou2rnWsDjiCAMW4FkZtkyvIXcJQ/OmeQ9bDKZcat3VodT2Mc+wNT/lUuuakuAOyWnB
HblLVLtdLon16F6Z3rf9hMYEp72zJ2/dfGbq9Q2Bcx+vx2buKBgFo2DgAQDHuSjL;

DEFINE LABEL 18
eJzjZ2BgSMs2SjGrXRMvWF+aVlD/J6ugXrR2U51i29yqa1Oel8XMjK6eP/tLrdoCwfqmLX+q+vd2lF3a
75jbv5dhFIyCUTDkAQCemhx4;

DEFINE LABEL 19
eJzjZ2BgyIzzLnsav6TgQKJ9bmD69PTq/OnpMwr+ZH0vOFo4o+Bkt0qO4IruTNmNZakRR2YnB1w9VVp4
raJm6w2GUTAKRsGQBwCGPRzu;

