-- HUMAN RESOURCE MACHINE PROGRAM --
-- 34-Vowel-Incinerator - SIZE 21/13 - SPEED 131/323 --

    COPYFROM 1
    SUB      0
    COPYTO   6
    COPYFROM 4
    SUB      3
    COPYTO   7
a:
b:
c:
d:
e:
f:
    INBOX   
    COPYTO   8
    SUB      0
    JUMPZ    f
    SUB      6
    JUMPZ    e
    SUB      6
    JUMPZ    d
    SUB      7
    JUMPZ    c
    SUB      7
    JUMPZ    b
    COPYFROM 8
    OUTBOX  
    JUMP     a


DEFINE LABEL 0
eJzjY2BguJFVt7E6v6P+UdH39LlVCQ4sdUxm0o0mzmvaVFLv9LhOYetftQ6ojGFVqXtxRc2/8qnN7ysY
RsEoGAXDAgAAAu0XUQ;

DEFINE LABEL 6
eJzjZmBgaE4r9Y9MsSypS4pavDvZdunTVNuleg2S04FSDBPqF/osqruVmVr7/z/DKBgFo2DYAQC3GhHJ
;

DEFINE LABEL 7
eJwTYWBguNiyImZvydT51fnn9ujkPz59Kr/m0vnipkdXy8Oe+lWlPrnYInrzSOfMC3d6ZE+k953bw9Zf
t3F737XV77oPzlHr5Jqxpk1y+tTmPzM0a5hWMoyCUTAKhhQAAIkqK6k;

DEFINE LABEL 8
eJzjYWBg0E+KCLyclpuQV/JnxvIm/pNqnWy3gMIMa9q+p0+o76j/Uhi1mDXh46kzge7PGEbBKBgFwwoA
AD9MFMU;

