-- HUMAN RESOURCE MACHINE PROGRAM --
-- 31-String-Reverse - SIZE 14/11 - SPEED 103/122 --

    JUMP     c
    COMMENT  2
a:
    COPYFROM [14]
    OUTBOX  
    COMMENT  0
b:
c:
    INBOX   
    JUMPZ    d
    COPYTO   [14]
    BUMPUP   14
    JUMP     b
    COMMENT  1
d:
    BUMPDN   14
e:
    COPYFROM [14]
    OUTBOX  
    BUMPDN   14
    JUMPZ    a
    JUMP     e


DEFINE COMMENT 0
eJyTZ2Bg6HB8p3Y8wFP7VN5eHSCX4U24s3VR+Aaf7lCPjOkhMrOnh1y/IBtifBUk980pa/89F8ujJh5T
TwqGfjgrn/Hh7M3GqSdBcre6i4pudbfU53Rx9Ym1K5741Jm1//w0xwrJ2d35X+Z25xstbqn/uvzgtIur
CtdfXAXRMwpGwSgYWAAAMBw45Q;

DEFINE COMMENT 1
eJwzZmBgqAsrMb3sb6jn4O5sLeVw0rPaYlXMEaPu/Cq9nKZ52r5TVbRn76zSqzlzxIjpNqOFzlNvm9+v
drmHv4/0X/CsKNz4ak88/+6TKZcWy2fU9c/MOFcmnzExfm/qUn3/FHnFt4kZEnuiGUyA1jA863Ks+NSp
Wd3SYd3B1VE+/1/H37UJ3d/2GvRznP4/af/l0GnGV7fPSDnfNufeAbtFlxarLTk4jW9Z/KKOZfcOgPR/
37gnc9GOxTmNN8XzQHytM21OG04fitQ6E9xqdlp9B8MoGAWjgGQAACGLXR0;

DEFINE COMMENT 2
eJzTYmBgsLetD7K3rUyqtkidxGu+aGW49dZKKQez6Hsuua4O7kKOU73m2X/3EXK87H/SE6icYVaRdcfZ
pu58pbYraRPaJ8ZzdXAHKrXZeJ9tOun5sd7Gmz1rT2ZJ4o+GnvhpPULx5fPZEnYti0522Gqe9m3v+2zF
Ey75U0/eKFc8ATLr9tRVMW1z3iZfWJCQ6rDtShpILH/FecspSyfGv5iXOqlq7t+1VXP5dzOMglEwCmgC
ABq7R90;

DEFINE LABEL 14
eJxzZGBg+OZ0Jc3YLiF1u3FC6h2DK2keGufKxJXWd+orHJy2VX7LtpUKQYfElaae/Kxy/cI2zesXeHRr
zoQZHj380nLXsovWJjO8baw71to5VtxzSUi95HppsYO7+g6gsQy/s4qKhDO78/1TxPM2xAS3+kV9nPAg
onx+UfjsnW/C1x57EDH15IkoxRN7U/+u3VSwvvNMRWWSZVV90OYqLbu48pb6rDLmeU/KOteAzJo8Wzzv
+ZQfDeIT6/o9evVWePRu2WbTp77DoH/Lts+TO9fMn8U878KCaT0Lljwrrln+wqxm+V6d/BUCdS9X1PXf
XSkz++5K0dUgc37sjiqt262+w//kubKYS2bRsXeOtzGMglEwggEAaN19hg;

