-- HUMAN RESOURCE MACHINE PROGRAM --
-- 38-Digit-Exploder - SIZE 25/30 - SPEED 218/165 --

    JUMP     c
a:
    COPYFROM 6
    OUTBOX  
    BUMPDN   10
    SUB      [10]
    JUMPZ    e
    BUMPUP   10
b:
    COPYFROM 3
    OUTBOX  
c:
    INBOX   
    COPYTO   3
    SUB      10
    COMMENT  0
    JUMPN    b
    COPYFROM 3
    SUB      11
    COMMENT  1
    JUMPN    d
    COMMENT  2
    BUMPUP   10
d:
    COPYFROM 9
e:
    COPYTO   6
f:
    COPYFROM 3
    SUB      [10]
    JUMPN    a
    COPYTO   3
    BUMPUP   6
    JUMP     f


DEFINE COMMENT 0
eJxTYmBg+Jrq7PQj5aTb6dglkVlBB/O2+3aVFvlfqlqW3TQXKM1QXNfkuL7e3TW3QTb0TUNdztqGwokg
8f8rrvmLLtyQFDNvb3biHO+ylNm3GhLnGE26Mf/gHJ8lbQsOrDg4R2Xz47a4rRH1s7adK5fczlIYvW1D
kuKW+WHqmySDPq2d7Gu/8pKP44oQP4ZRMApGwYAAANhQP5E;

DEFINE COMMENT 1
eJwzZGBgaElwdhKICfGz9vmTxenOUy7oItt8L6xpbktCwHKgNMP6+vfGeg32s0HsG/O9PVbObMpfM+Na
7cqZWyarzmaYIzX/5KLJC90X8i45OOf/iuedlqv7KypXm6XvXpWb8H/Fo4i+xWc9QxZyuM2e1+YCMqNp
f5f7/S17s5duCqlZuim1Y9Hmz5NmbeNYNGGX6Oo/B2evf3g6ZNXEi20LuK9Yz+C4mtvHcXV24+nLHCUT
L5ql3z77PDrj5K2goqMhfn8OXvKZsOuaP8MoGAWjgGwAAAxQXyM;

DEFINE COMMENT 2
eJxzY2BgCHUS9JnueM3fzrir9JReQiuXfmqHm8GKrvl2pVOmO1rPACphCIo+6NAXs3cmiP2zOiLweFlA
pWeZYht7udEkx0qGOdtrOBZpN3Ytlmtjmd/fbTa1acLjth+TecpLplZlbpuSGXuk/5LPxS531/mtR51X
NXK4Gdaf9Syum+wLMu/rmlKLwEV7s0MW8pQLLZrdeHbx8862ZRsm7F5lNlV/vdnURZv1+mdsT2jl2XO0
8PjeDUls++6Feuyd7HtlB4ND3FZrm9Ubqqy3rtlrCzLL/WqAd+qpnRnvjp0sMT56rXbT0YTW3OOZ3Y9P
FU4UvWA21fVa6ZSvt3P7nj6MqE983Fak9HhDkvrDmJAPd896Vt5qc2m87u568kq/F8MoGAUjBAAA+7yC
Ug;

DEFINE LABEL 3
eJzjYmBgKEw/6ZaXcclnRdbe7Fv5R+cHFstuPFtybbVdVWb3xzqjlPmtTY4Mo2AUjIJhCQCmBRK5;

DEFINE LABEL 6
eJxjY2BgEC9MjZpaaJZ+vUB2I5DLEFb4SIsBCxCImbzyWPzJRSD2suzXcY9yjs5/mp3Q+jR7Z8ajnFtB
8nmzg2/lp0bVVr3vN66zn63dmNuX3MJTntCql6jQGhMC0vd70pLILVPnh62cKRvKtfRe6KPNSyJB4tWr
StPsV85vsVx9dP731Uu2YrN/FIyCUUB9AADq0jjY;

DEFINE LABEL 9
eJwTY2BgSMzNNapM+WNzIo7DrS8mxC8oWi36QrR1Vmfctdrdybl9JWmfJ63IKp0yN0+vP6wwtYO/RLLB
ueJg3p+q+WH/Kzncmiv22p4q/Wx2tfC1QVr2Yu1PaYu1GUbBKBgFQwIAAMa0J5o;

DEFINE LABEL 10
eJyTYmBgeJTj7jqjoG4WkMmwcuZJt2N9t4ICupdERnS8T4xt+5Ol0BpQKdf2uG1W+5pe356Dc9j6ORb9
m+i95NuUrsW6M9oWpMyumxWycEk7/2LR2rOL3Yv7Fn9OCVk4P2zm/IhA+bmXfN5ND/BmGAWjYBQMSgAA
i+Qxkw;

DEFINE LABEL 11
eJwzZGBgqPLRM/7pc8knP6B0CpDL8L/S2kawOMD7esHs4Li8zynyeXU5s/Ov1YoXPm7jKS2d8r/Sfvba
hr0zY9sKJ/L1KLZx9N1qcO0XrGKecLSQecLOjJZ+rTiOvtnBAd1nPaPamxzNar9b/q8stegoM7MEmf9r
VZW1z5KjzuELQvzmzdWKi5+7JXXagmu1vEty+9yXmU39v2LvzM1rD85R31Q3S2Tn+/7e3akdHnun1znv
N0tn2a8WzbMnxO/WNhbntE1/bPTX77BiGAWjYBSQDQD0pVdh;

