-- HUMAN RESOURCE MACHINE PROGRAM --
-- 38-Digit-Exploder - SIZE 139/30 - SPEED 103/167 --

-- Based on binary search
-- Can be more optimized

    COPYFROM 11
    ADD      11
    COPYTO   8
    ADD      8
    COPYTO   5
    COPYFROM 10
    ADD      10
    COPYTO   7
    ADD      7
    COPYTO   4
    BUMPUP   9
    ADD      9
    COPYTO   6
    ADD      6
    COPYTO   3
    JUMP     l
a:
    COPYFROM 9
    SUB      9
b:
c:
d:
e:
f:
g:
h:
i:
j:
    OUTBOX  
    COPYFROM 2
k:
    OUTBOX  
l:
    COMMENT  0
    INBOX   
    SUB      11
    JUMPN    al
    SUB      5
    JUMPN    q
    SUB      8
    JUMPN    o
    SUB      11
    JUMPN    n
    COPYTO   2
    SUB      11
    JUMPN    m
    COPYTO   2
    COMMENT  3
    COPYFROM 10
    SUB      9
    JUMP     ab
m:
    COMMENT  2
    COPYFROM 10
    SUB      6
    JUMP     aa
n:
    ADD      11
    COPYTO   2
    COMMENT  1
    COPYFROM 3
    ADD      6
    ADD      9
    JUMP     z
o:
    ADD      11
    JUMPN    p
    COPYTO   2
    COMMENT  4
    COPYFROM 3
    ADD      6
    JUMP     y
p:
    ADD      11
    COPYTO   2
    COMMENT  5
    COPYFROM 3
    ADD      9
    JUMP     x
q:
    ADD      8
    JUMPN    s
    COPYTO   2
    SUB      11
    JUMPN    r
    COPYTO   2
    COMMENT  6
    COPYFROM 3
    JUMP     w
r:
    COMMENT  7
    COPYFROM 6
    ADD      9
    JUMP     v
s:
    ADD      11
    JUMPN    t
    COPYTO   2
    COMMENT  8
    COPYFROM 6
    JUMP     u
t:
    ADD      11
    COPYTO   2
    COMMENT  9
    COPYFROM 9
u:
v:
w:
x:
y:
z:
aa:
ab:
    OUTBOX  
    COMMENT  10
    COPYFROM 2
    SUB      10
    JUMPN    a
ac:
    SUB      4
    JUMPN    ah
    SUB      7
    JUMPN    af
    SUB      10
    JUMPN    ae
    COPYTO   2
    SUB      10
    JUMPN    ad
    COPYTO   2
    COPYFROM 10
    SUB      9
    JUMP     j
ad:
    COPYFROM 10
    SUB      6
    JUMP     i
ae:
    ADD      10
    COPYTO   2
    COPYFROM 3
    ADD      6
    ADD      9
    JUMP     h
af:
    ADD      10
    JUMPN    ag
    COPYTO   2
    COPYFROM 3
    ADD      6
    JUMP     g
ag:
    ADD      10
    COPYTO   2
    COPYFROM 3
    ADD      9
    JUMP     f
ah:
    ADD      7
    JUMPN    aj
    COPYTO   2
    SUB      10
    JUMPN    ai
    COPYTO   2
    COPYFROM 3
    JUMP     e
ai:
    COPYFROM 6
    ADD      9
    JUMP     d
aj:
    ADD      10
    JUMPN    ak
    COPYTO   2
    COPYFROM 6
    JUMP     c
ak:
    ADD      10
    COPYTO   2
    COPYFROM 9
    JUMP     b
    COMMENT  11
al:
    ADD      11
    SUB      10
    JUMPN    am
    JUMP     ac
am:
    ADD      10
    JUMP     k


DEFINE COMMENT 0
eJzTYWBg0I95FOETezA8Lq807VZ+adr3gp0ZYYWyOd8LOErU4ydPehszfzZQGYN1e4D3k2bFttZmlvkg
/rNZjyLaZwkmc89cUpA1U3K6xqy6WYtnz5+9Y/782XmLt0xmX7a3SWW5e4zn0mv+eYsn+9rMm+wL0qe3
e4tf8M7MWLMd7xOjt22ojN62ouvLjpiZ53cdnPNk38E5cgdjZpYecW6fdFSrdNLRg+FXjlgHix35HqC2
73sAwygYBaOAqgAA8I5SNg;

DEFINE COMMENT 1
eJzjYGBgUCtZn2bW2J38t7872bY3rSyuTWjjt2azU/OaN15hGAWjYBQMawAAQBQOQw;

DEFINE COMMENT 2
eJyTYGBgmNZ0POhc3YOQtBrZqGnlu9OnlT/I+lYhWyDW0d2v2iU4W7UrfdG+9rdr/Vqctp6rK94ZV128
81+l/7ZvFSdWfavwW7CsUnD2s0azjq99ReVrJ2gWsk48kRE6YXqKXwtLBMMoGAWjYFADABJjL1M;

DEFINE COMMENT 3
eJwTYGBgaGt4EPKu/EpwW6lj7Lli1rxzxfUVZmWybcsq03vU6ot7+dq7K8U6BPPFOrqTZTuj4s/VsW7I
qy0+n1fLdodhFIyCUTCkAQAFAxr/;

DEFINE COMMENT 4
eJwTZmBg2NZmGhPWahrj1lyUKFabVtZXtmRiWfGGFflFM/bkF/mfKSsuPq9X2nBhWlPx+aMdbMeudp08
8LRHaGNvT/dS3e7ohXFtP2eYNV6ZyjAKRsEoGHIAAJu9JUI;

DEFINE COMMENT 5
eJwTY2BgWFdV5B1WtTtwXoVg5LOy3enPymTbppVHdS+r7O5/18Q6a197+iLVrg0rart+rivt1Nrs1tyz
263i6kH/vIeH3HOvHpyek74DaAxDWV13cmmnbNTbXtkohlEwCkbBkAAAJIIpZQ;

DEFINE COMMENT 6
eJzjY2BguNfww0E/S25OfvqJVfnpQhufZ8ttelb2c11rd/fSpz3Fi4FKGMwanYrNGhdXl9WdWJVXK3SX
YRSMglEwLAAAshEZRg;

DEFINE COMMENT 7
eJwTYGBgaCvdHfi1b33A1z7H2Nbu3el5tZrtyyrTe5a1/JwxtffEKt9+1g1L+522+vYX72ztfngork3r
pF7pksvzc5dcZhgFo2AUDGkAAIinINQ;

DEFINE COMMENT 8
eJwTZmBgWJ/vFxee/yBkf2GX771SXw+2ak3Xa/Wmbu+airy/NU/3+9fCEvGvZXGqXVNUqV7phhXr881O
/c/beGV9/tXr8yp+3XJr/nVLtevkNYZRMApGwZADAAZkJrI;

DEFINE COMMENT 9
eJxjZWBgcGsu8m5reJN9rNZ/27bqnosMo2AUjIIRAwC2lgi/;

DEFINE COMMENT 10
eJyzYmBgiNKVjWLS3bMSyGTQtF2cWmkjW1BorVl40Eq27aCV4OyT1mbzKm3qlzy027CC02XPygee0Qs9
fPZMDvDVbA/wXVxt6FmUeNLNL+6no19cp92JDJA5zxM02/kLNdtB7LOdgpGlnevTcjs0C8U6IPasnV2X
1Dt9fU3rtJ8z7k5zmr92dvFinYVac3sWsc7yWTp9Qsgys441y/bUblleVL5lOWueyaK0BJC+z7ui4h/v
uJLZvD2tTHv72+m3t5vNe7wjemHyvvRFpw+YzbM+smTi4mMPGoA4y/loXdLtQ6Yxu/eZxjCMglEwCrAC
ANlPZrE;

DEFINE COMMENT 11
eJyTZ2BguJtkHXw3aX7YheizCcqh9rnbfT9X3/He22Tsr9jmEezc3hcTMGFy2sE5QKUMkjV7bf9ULSm4
X7m36X6lz26Q2PyJW/zY+jNjz/Tklp/pMVq5vO/Wuv7pt9Zxz9y5NnFO5iKbedem/Jrn3D573pr4Z7Ou
+RtM5/HcM+m1O8MoGAWjYMABACujOtY;

DEFINE LABEL 2
eJwTYWBguJ+1PqA9a3qVeXZ93/kMrblAIYbledP9+Av94p6VORXPq1hfo1a/YdK9Brk5ILlvzUXebs2y
Uc8a16c9a9QsNGuMKjVrPDFlWpPfAoZRMApGwZACAHNJIRU;

DEFINE LABEL 3
eJwTZmBg+Nj12v1K52t3xta60IL6W5m7qo8WWhZcmxKXZz3DsmD+bMPig3MspsyfDVTKMKmrLnRSV1dc
bdvkSYytf9a3NvfvbW1OPXu8acV5hlEwCkbBkAMA5FokfA;

DEFINE LABEL 4
eJwTYGBgEKsVjOSrkY1aVxUVf680rexayYm6c8VvGo8X1ffd7a7vAyphWNaiGT2veXrKtKafTdOahI6D
xFjnbNjHMApGwSgY0gAA2pIadQ;

DEFINE LABEL 5
eJwTZWBgUM/cnX48/Urm+pSo0vvxbxoVYmXbAiKWTLQI1ZpbEOO3YH+a34L7WXJzjhfJzQEqZ7if9aZR
P6t48fkMoY3yGQ8PgcT21QgdB9FXu94eZhgFo2AUDBkAAPZwIn8;

DEFINE LABEL 6
eJwTYGBguFT0vOhSUWna++LM2I6yg+F2VdbBbxpiQhJaM2PvtP3JutNmVre/VbHtfP3BOe+LI46IFK04
X1zEe9m4i/cywygYBaNgSAMAIhgfaQ;

DEFINE LABEL 7
eJzjZ2BgWJ//IGt9/vq0suK0hHVVaQnn6nantzWklbU1XKkvq7sy1a+SdUNZsdyJtlLn0+tanU8DtTD0
Tv95hGEUjIJRMOQBAD1vG8Q;

DEFINE LABEL 8
eJwTZmBg6M/WLPyey5p3vOhNNl/Nj5x9NU7F+2reNKbVOHX+q+zu7yt7O315Xv0S+5wTq8oz6nedz1iy
V64uejtQK8Pf/hl7QHTLwg37GEbBKBgFQw4AAFbbI38;

DEFINE LABEL 9
eJxjZWBgeNNwzX9TXW75prrHc6fWau1iGAWjYBSMGAAAA/sJUQ;

DEFINE LABEL 10
eJxjZ2Bg2F7gGMtfmFYWnp++6H2O1kmgEINavfNphlEwCkbBsAcAhlUI+Q;

DEFINE LABEL 11
eJzjYGBgsCt3jLUrL+59V242D8hlkO2MXgiir06tX8IwCkbBKBjWAABn6Ql5;

