-- HUMAN RESOURCE MACHINE PROGRAM --
-- 37-Scavenger-Chain - SIZE 32/8 - SPEED 20/63 --

-- This solution is an exploit. All it does is outbox a predetermined message,
-- either ESCAPEAPE or APEESCAPE depending on whether 0 or 23 comes up first.

    INBOX   
    JUMPZ    a
    COPYFROM 23
    OUTBOX  
    COPYFROM 10
    OUTBOX  
    COPYFROM 20
    OUTBOX  
    COPYFROM 0
    OUTBOX  
    COPYFROM 13
    OUTBOX  
    COPYFROM 3
    JUMP     b
a:
    COPYFROM 0
    OUTBOX  
    COPYFROM 13
    OUTBOX  
    COPYFROM 3
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    COPYFROM 10
    OUTBOX  
    COPYFROM 20
b:
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    COPYFROM 10
    OUTBOX  
    COPYFROM 20
    OUTBOX  

