-- HUMAN RESOURCE MACHINE PROGRAM --
-- 31-String-Reverse - SIZE 112/11 - SPEED 58/122 --

-- This solution is floor-specific. The strings to be reverse can be up to 13 chars in length.
-- This is the same limitation as the pointer based solutions. The solution can be shorter by 
-- reducing this maximum. It also accepts empty strings (just a zero).

a:
b:
c:
    INBOX   
    JUMPZ    a
    COPYTO   0
    INBOX   
    JUMPZ    ab
    COPYTO   1
    INBOX   
    JUMPZ    z
    COPYTO   2
    INBOX   
    JUMPZ    x
    COPYTO   3
    INBOX   
    JUMPZ    v
    COPYTO   4
    INBOX   
    JUMPZ    t
    COPYTO   5
    INBOX   
    JUMPZ    r
    COPYTO   6
    INBOX   
    JUMPZ    p
    COPYTO   7
    INBOX   
    JUMPZ    n
    COPYTO   8
    INBOX   
    JUMPZ    l
    COPYTO   9
    INBOX   
    JUMPZ    j
    COPYTO   10
    INBOX   
    JUMPZ    h
    COPYTO   11
    INBOX   
    JUMPZ    f
    COPYTO   12
    INBOX   
    JUMPZ    d
    OUTBOX  
    INBOX   
d:
e:
    COPYFROM 12
    OUTBOX  
f:
g:
    COPYFROM 11
    OUTBOX  
h:
i:
    COPYFROM 10
    OUTBOX  
j:
k:
    COPYFROM 9
    OUTBOX  
l:
m:
    COPYFROM 8
    OUTBOX  
n:
o:
    COPYFROM 7
    OUTBOX  
p:
q:
    COPYFROM 6
    OUTBOX  
r:
s:
    COPYFROM 5
    OUTBOX  
t:
u:
    COPYFROM 4
    OUTBOX  
v:
w:
    COPYFROM 3
    OUTBOX  
x:
y:
    COPYFROM 2
    OUTBOX  
z:
aa:
    COPYFROM 1
    OUTBOX  
ab:
ac:
    COPYFROM 0
    OUTBOX  
    INBOX   
    JUMPZ    c
    COPYTO   0
    INBOX   
    JUMPZ    ac
    COPYTO   1
    INBOX   
    JUMPZ    aa
    COPYTO   2
    INBOX   
    JUMPZ    y
    COPYTO   3
    INBOX   
    JUMPZ    w
    COPYTO   4
    INBOX   
    JUMPZ    u
    COPYTO   5
    INBOX   
    JUMPZ    s
    COPYTO   6
    INBOX   
    JUMPZ    q
    COPYTO   7
    INBOX   
    JUMPZ    o
    COPYTO   8
    INBOX   
    JUMPZ    m
    COPYTO   9
    INBOX   
    JUMPZ    k
    COPYTO   10
    INBOX   
    JUMPZ    i
    COPYTO   11
    INBOX   
    JUMPZ    g
    COPYTO   12
    INBOX   
    JUMPZ    e
    OUTBOX  
    JUMP     b


