-- HUMAN RESOURCE MACHINE PROGRAM --
-- 06-Rainy-Summer - SIZE 20/6 - SPEED 20/24 --

-- This solution is level-specific (quantity-limited input).

    INBOX
    COPYTO   0
    INBOX
    ADD      0
    OUTBOX
    INBOX
    COPYTO   0
    INBOX
    ADD      0
    OUTBOX
    INBOX
    COPYTO   0
    INBOX
    ADD      0
    OUTBOX
    INBOX
    COPYTO   0
    INBOX
    ADD      0
    OUTBOX
