-- HUMAN RESOURCE MACHINE PROGRAM --
-- 23/330
-- I've written one linebreaking function too much, can you tell?

a:
    INBOX   
    COPYTO   9
    COPYFROM 14
    COPYTO   8
    COPYTO   10
    COPYTO   11
b:
    COPYFROM 9
    SUB      8
    JUMPZ    e
    BUMPUP   10
    SUB      15
    JUMPZ    c
    JUMP     d
c:
    BUMPUP   11
    COPYFROM 14
    COPYTO   10
d:
    BUMPUP   8
    JUMP     b
e:
    COPYFROM 10
    OUTBOX  
    COPYFROM 11
    OUTBOX  
    JUMP     a


DEFINE LABEL 8
eJzTYmBgEBD9bBYu9DxaWlCxTVpQcMVNwSVbgcIM/aJNju0SXe720tMDKmX1ErfJORdsk+uv2Ck7vc5W
RrKhRyyiHqSuwnRv9iHDuhxPfecCEe3pdbM13vfP1tgyOUzLfnaHftPcOuOd07Kt5rek2ZwrT7NxLgDp
WRKiFv06UCvO1vtPFrNnW9Fx90tVx90TWhm9SqeU+p1c5B9jfjgo+s8x1RCWs8fdj55lGAWjYBTQBAAA
VsI/AA;

DEFINE LABEL 9
eJzzY2BguClYaHpBZ4cVkMlgLnfUeZtcwHIQO83GLH2HaVWmnTFD3iFD7zIXQ62eP8alUypMzaZ+Mi+c
qGaT0KpiK1qbbGufm2BnnZVgZzQp1OncUpBe7SCGvM9+r3u2+0qus/AVXb3dt2musX/plDWBr3uWB7/u
uR1eOFEgxmgSSK144eTq2fmCVWnZk6sL0+81m6SpdX5Nze0rSTOalJfxY2pi7o+pk4u0enpLYpp6S1Z0
TS4SXHG9QG377Hy9vXPzNuzLyyg7tC217BDIrOzGvTMvdjXN/TG5ae666dYzdGdsmPB56vPO35MU2470
K7Z59ap1TurK7ZvV7jzvTlvA8jltatt9e3L31E/U2wvSn7CFo+T7apb5lqvPLbVcHbH265r5m1ZsXLFj
1rbMnSD5/ytmNyZvXtLOQCJo3XdrHYjWmHW08PFsnvLb8y5VVa5+3Ba9bU3viwd7Z5Jq3igYBdQCADh2
mYg;

DEFINE LABEL 10
eJzjY2Bg0OBJ0AwX+mPjKrkkcrfMn6yvcgGVmcq31gGlGE7pHXQQ1zrqrK4S4P1D9lGErMDnSWq8/csY
RsEoGAXDAgAAHfMThg;

DEFINE LABEL 11
eJzjY2BgqJG5p75T1szyq5xe4mf5g3m6SmviVyoviTyhX2i611hWHaiEQVfpYN4P2bpZNTK31tlLHz3L
MApGwSgYFgAA7g4Ufw;

DEFINE LABEL 14
eJxzYWBgCBeSDKqRmR4wWTsi8JDhvdBqE624P8bvE5mMPqckqjXlf1A4V57E577QgPPWuuU811Z3il9b
za8bsyHPMnMnUDuDh3tXaZXPtdrlwfeaQ6JSOw4kruj6m6TYVpMs2WCTHFDplMiQ5x7/PT0oujB5efDn
lH9ebUWuHqK1J93UOrnd9s7kdgtZ5eG+Ysc/r7oTVT5Npw0Cjp59Fux8Jil0zW6Q+WdLTpbcyq+b9SJr
ydbrBXWzJheVTjlbYjTpUEXhxO01pVMM6/fOzG48uQikVnzB47Zns2KajKbJNu+bmNrh1ft5UlDX0fli
nddWX+t4vCW0c8UOjj6jA0bTfhzOmvn5wN25kusi57/uUZ29N/vd9PeJDKNgFIwwAAB0NH+a;

DEFINE LABEL 15
eJzjY2Bg4BbfYs4t7lzgJR5QySExufqDwuTqP8YxTbtMIuqB0gxuBgcdPPU3JMVo9C+LU5+/SV697BDD
KBgFo2BYAAAtBxJH;

