-- HUMAN RESOURCE MACHINE PROGRAM --
-- 40-Prime-Factory - SIZE 137/28 - SPEED 51/399 --

-- This solution is level-specific (patterned and quantity-limited input).
-- All three inputs are between [2, 20]. 

    BUMPUP   24
    BUMPUP   24
    COPYTO   23
    BUMPUP   23
    ADD      24
    COPYTO   22
    ADD      22
    COPYTO   21
    BUMPUP   21
a:
b:
c:
d:
e:
f:
g:
h:
i:
j:
k:
l:
m:
n:
o:
p:
q:
r:
s:
    INBOX   
    SUB      21
    JUMPN    u
    JUMPZ    ad
    SUB      22
    JUMPN    t
    JUMPZ    ah
    SUB      24
    JUMPN    ai
    JUMPZ    aj
    SUB      24
    JUMPN    ak
    COPYFROM 24
    OUTBOX  
    COPYFROM 24
    OUTBOX  
    COPYFROM 22
    OUTBOX  
    JUMP     r
t:
    ADD      23
    JUMPN    ae
    JUMPZ    af
    SUB      24
    JUMPZ    ag
    COPYFROM 24
    OUTBOX  
    COPYFROM 24
    ADD      22
    OUTBOX  
    JUMP     f
u:
    ADD      22
    JUMPN    v
    JUMPZ    z
    SUB      24
    JUMPZ    ab
    JUMPN    aa
    SUB      24
    JUMPZ    ac
    COPYFROM 23
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    JUMP     p
v:
    ADD      23
    JUMPN    w
    JUMPZ    x
    SUB      24
    JUMPZ    y
    COPYFROM 24
    OUTBOX  
    COPYFROM 24
    OUTBOX  
    JUMP     l
w:
    COPYFROM 24
    OUTBOX  
    JUMP     i
x:
    COPYFROM 23
    OUTBOX  
    JUMP     s
y:
    COPYFROM 22
    OUTBOX  
    JUMP     m
z:
    COPYFROM 24
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    JUMP     q
aa:
    COPYFROM 22
    ADD      24
    OUTBOX  
    JUMP     k
ab:
    COPYFROM 24
    OUTBOX  
    COPYFROM 24
    OUTBOX  
    COPYFROM 24
    OUTBOX  
    JUMP     n
ac:
    COPYFROM 24
    OUTBOX  
    COPYFROM 22
    OUTBOX  
    JUMP     g
ad:
    COPYFROM 21
    OUTBOX  
    JUMP     a
ae:
    COPYFROM 24
    OUTBOX  
    COPYFROM 24
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    JUMP     b
af:
    COPYFROM 21
    ADD      24
    OUTBOX  
    JUMP     d
ag:
    COPYFROM 23
    OUTBOX  
    COPYFROM 22
    OUTBOX  
    JUMP     c
ah:
    COPYFROM 24
    OUTBOX  
    COPYFROM 24
    OUTBOX  
    COPYFROM 24
    OUTBOX  
    COPYFROM 24
    OUTBOX  
    JUMP     e
ai:
    COPYFROM 21
    ADD      23
    ADD      23
    OUTBOX  
    JUMP     h
aj:
    COPYFROM 24
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    COPYFROM 23
    OUTBOX  
    JUMP     j
ak:
    COPYFROM 21
    ADD      22
    ADD      23
    OUTBOX  
    JUMP     o


DEFINE LABEL 21
eJwTZWBg+Oz3KCI8ss3FPX6DyenYJkeBmOfRIVE/ps6MeL1rTrjeXqASBp7S0rTjZaVpjpV6icV1gj6x
bZ/N5reaWT5vKkzWbJpcrdm0ZOvzJp9LS5snX2cYBaNgFAwZAAChMiSa;

DEFINE LABEL 22
eJyTZGBgOB0bEchfIuov3d7m0t9tbw8UYmiLt7c/HXvSLSSqMHlmhHvxnHDFtg/p0+sCiydX/6y+Vvuy
UbY5oXXDBImOtgVXOmM2XOk0OiDRwXL2SXPA1YL66bcCi6ffKknjvfw3ifcywygYBaNg0AIAy1csdA;

DEFINE LABEL 23
eJyTYGBg0M+wtrmV/9lse80aQ72G98ZLm+vsFrUcdV7UIujzvOlRhF2Ve7FMvmKbUXpmN0NSZndZama3
Yu6GCcV1bQsK6s8t1W40OlBQP/n61lqlR3ZVua+uF2i9SMm5d39GgdIjhlEwCkbBoAYAuEUsfA;

DEFINE LABEL 24
eJwTYGBgmFp4MO9Uqaj/z+o2l+dN9vaxbfb2Eh1Hna90Cvpc6ZwfFtu2M0O7cXJ1YHHT3JQc0dUMSVVH
V2RVHbWanLiZYRSMglEwpAEAakkcJw;

