-- HUMAN RESOURCE MACHINE PROGRAM --
-- 28-Three-Sort - SIZE 49/34 - SPEED 77/78 --

    JUMP     e
a:
    COPYFROM 0
b:
    OUTBOX  
    COPYFROM 2
c:
d:
    OUTBOX  
e:
    INBOX   
    COPYTO   2
    INBOX   
    COPYTO   1
    INBOX   
    COPYTO   0
    COMMENT  0
    SUB      1
    JUMPN    h
    COMMENT  3
    COPYFROM 1
    SUB      2
    JUMPN    g
    COPYFROM 2
    OUTBOX  
    COPYFROM 1
f:
    OUTBOX  
    COPYFROM 0
    JUMP     d
g:
    COMMENT  1
    COPYFROM 1
    OUTBOX  
    COPYFROM 0
    SUB      2
    JUMPN    a
    COPYFROM 2
    JUMP     f
h:
    COMMENT  2
    COPYFROM 1
    SUB      2
    JUMPN    k
    COMMENT  4
    COPYFROM 0
    SUB      2
    JUMPN    j
    COPYFROM 2
    OUTBOX  
    COPYFROM 0
i:
    OUTBOX  
    COPYFROM 1
    JUMP     c
j:
    COPYFROM 0
    OUTBOX  
    COPYFROM 2
    JUMP     i
k:
    COPYFROM 0
    OUTBOX  
    COPYFROM 1
    JUMP     b


DEFINE COMMENT 0
eJzTYWBgCAiost7uu8VP0KVpC5DLwBdY6HMmcIsfW4hRypGQ50WLE2YfA4lb+8TMnOQ/f/aNiPmzQfzn
ZW2dc6vaOp80M7SC+NOnBHhPn1IXWjX5faLDRN6+hxO6FrP1M5wCyfnOsA4OXGQd/Gnhowj5ue8Ti6Y9
L5Ke3F+xeHZu+eSFn6vZl+1tal7O29e8/OAcz6WCK/IWl67+Ne/WOu6ZshtB+tfMkN1oMQXCHgWjYBRQ
DwAAkvpJEQ;

DEFINE COMMENT 1
eJxTZGBg4Iq7Z2ceWeizO/xRhH1YaRpfYOJmoDADU6KZZWIig8PktNI0/gzR2ri83D0g8ZAo5/bIlNQO
EHtX9edq7d4NlSD23pWFPp5Lt/gFLqoL/TWvNK1u7tHCurn9FQfmmNUdmOO+8O7cnWsj5y/Z+n9F05YZ
q2U3rl0vuzF7w611DKNgFIyCAQMAO3o2bQ;

DEFINE COMMENT 2
eJxTZmBgqIwws6yMsN8EZDJkxolaMCWKWlxNVXQ8m6HnlZZ9MDwtWzDZJE02Rz6pKT8yhaMkMF2r1LLA
rM6vxLl9bUndrLDCzEWJiYIrpkXuXAsy43z986KbkzdUgtjVq/S84lbyeKosL/QxWXg2QXzBzozI+Zeq
IucfnBO46P2yo8v+rK9eZb/JbZPsRoZRMApGAd0BAKI6NvQ;

DEFINE COMMENT 3
eJzTYGBgsPbpM17kGWG1yPNPlrWP2gJrH6OVQGEGj+Aq6wOJs23qkhQd65J4PBMTr/mHRL1PVA7dmXEk
RDbnQWhC3t2kJQWRKVqlkSlmdW3xWyb7xMbMlIpwX6gdtGYJyIy1JUcLC+q9y9Z3e5eB+MVrP5vJrPps
5rjCzLJ7SarzhkUB3r/m7cz4NQ9oxvwNlfyLGVqrV12bcmlt3aw/W9UWMIyCUTAKaAoA9QhCGw;

DEFINE COMMENT 4
eJxTZGBgYEqMsHoav9fWJzYmJCSqvyImnLfvb5jk9Aeh82cDpRl+JecalaUyODzKWROfXfq6R7Nsy+SO
sjVLQHKrY/sr0rK9y0DsL7V/svqn/8kCsUXW7rV1XKHouGJpm0v3ktfueYtjQvgXh6TmLa5q8Fx6sttx
xY+pW9fUzTLbAbFjFIyCUTAwAABZYDcw;

DEFINE LABEL 0
eJwTZmBguF/Z5rK25HuASJF7jGPuiq5HOdemvMo8tzQvY8lWoDRDdDWDg1ntNf9VjaVpnE32ua3NWqWT
unx2g+Sq8yPqO8r2NhXU721iGAWjYBQMOQAAtQMfdQ;

DEFINE LABEL 1
eJyTZmBg2Fp4z86ygMfzVr51cHU+b9/evMKJKjkRR4BSDBOKn+ueKj2q86ahz5iz6ZLpk2ZnpyfNk31b
m62DN9WFpIYVXqpybvlcbd2+osu6PWZmbZv7woTWc0u9G2U3fqldsvVPFcdOkaL+va8yN+xjGAWjYBQM
OgAAIGoxrQ;

DEFINE LABEL 2
eJwTYmBgaG2usp5aW2XdULnXlqd0hatI0WTf6vyD4TL57jF782Y3Vuev6Couejz3fXHmIp7SkFXJFfab
oqubtjxpXrL1SufOteu7BVcwjIJRMAqGJAAAmJAhkA;

