-- HUMAN RESOURCE MACHINE PROGRAM --
-- 20-Multiplication-Workshop - SIZE 15/15 - SPEED 135/109 --

    JUMP     c
a:
    COPYFROM 2
b:
    OUTBOX  
c:
    INBOX   
    COPYTO   0
    COPYTO   2
    INBOX   
    JUMPZ    b
    COPYTO   1
d:
    BUMPDN   1
    JUMPZ    a
    COPYFROM 0
    ADD      2
    COPYTO   2
    JUMP     d


DEFINE LABEL 0
eJzjYWBgKEzvWvwq82jh7PxHWvsrU6MmdXUtBgozXOzyXgKi8zJOlniX2ufKtZWmMYyCUTAKhhUAAI6c
Ejk;

DEFINE LABEL 1
eJyTY2Bg+Fm9WHt9fUzT+3rneYb1giuAQgxu5WsMHSvVdI3r7qnLtU1XYp4wXWnNjPkaqrNTdJTmaBko
zSk0fTFzr+23KV3usW0xIa79MSGJc9SifZYUJncuLU1zX3Yw7/SS6XUTF6V2zJz/eZLWzLYFAt3XVhvX
zd90qjRxM8MoGAWjYFAAAMSwNBE;

DEFINE LABEL 2
eJzjZGBgsE/S2pWZlbnTuC53T9VkrV1AIYYDifeaj5bfarjZPruRAQ/YYVqXs8qqvyLaoWr6dUfepSAx
jeAdVrmBVZm5gdYzngU3ze2LOTiHI955HkSOpfBGRF0OiK0a8tnsXtgOq5Aoa5uvqdY2ILFFLV3u1wty
EyQLNiRJFtTlXC+4VBVclNDqXbpl8t6qgOXba6avKaiP2RDa+XhLbJvWrjcNdSckC67dXJArehOk//WM
iMAHcxTbAhepbb+wSGsX75I1u1mXq21vXDF/k/3K6WuqV0XUb16rGAFSG7BL1N9vd2rUmd3eZRN2bTno
vcf8cNaJH4fvndlyUPpc4X6QmtOXZUP/v5cNBbHf3nsUkf6wKf/pQ8GqxY/sT+ILl1EwCoYKAAAwH38F
;

