-- HUMAN RESOURCE MACHINE PROGRAM --
-- 17-Exclusive-Lounge - SIZE 12/12 - SPEED 28/28 --

a:
b:
    INBOX   
    JUMPN    d
    COMMENT  2
    INBOX   
    JUMPN    e
    COMMENT  0
c:
    COPYFROM 4
    OUTBOX  
    JUMP     b
d:
    COMMENT  3
    INBOX   
    JUMPN    c
    COMMENT  1
e:
    COPYFROM 5
    OUTBOX  
    JUMP     a


DEFINE COMMENT 0
eJyLZmBg2OljZNbkuULP201RS8U2QfOL2XNdR6NC0w59a5s+3S53P91bQZ76RikNRiyFu0zaioKd24o4
3btK93iH1Gz0n9+yPmBN7/oA6xlF/kfnl/sGLG/1kN0o6KK0RcX28ZZmQ61dQCsYUnJ4yl9lnisvTA+p
+ZWc0Gqf9LrncELVdJeEk4v+Js1eb5Seum1FVubOq4WZO3lKn29nqZi/6X9lyKraqoNzGirNph4tf99/
tXB+S1jh7MarhdPrZPIDKm/lX6t1rjCbur/SZ8mfqpBV7+uVtqQ2P98Oss+rV7DKq7dwYn93yCrfns+T
XPuv1TZNmFy9Zerk6o3TRGvzp0s2rJuu2GYwvWluyuzZjfPmhtRMW3CpymfJ7EbPpSu62JdVTT+xNHUb
yCyZbXWzsk7Uzbp9tmr6lAuFE4UvLmkXvXCvecmpkJqqQ5eqJuxa0TV1x4YJ17f/mDpj+6UVgrvmb+ra
83z7n4Pv9xoce79X+pzadu4ramB3jYJRMNgAAOt8sJU;

DEFINE COMMENT 1
eJwzZGBgcDR6b+xiKBvqqd9Vyq+7ouuCjvWMSE217TM0tXZN08rdY2dcuP+V1eMt9+1EV7N5PO884iHb
7Ow5uZrZ83v6RWceTzn7Ors3lqUWhhalFkDjGGLCP09SDp28UjfQ/DCIrxD2OQVEp+TYn7xaWDWdvVwy
6FDFJR/r6ks+hvURgfnTecpB8urZK7r8SjK7NZuqpoP40xYcPXt54eMtgYtCavoWy4be3zI/7NJOtWiQ
nNbMuln2K//MENthNpVhFIyCUUA2AABBfUrq;

DEFINE COMMENT 2
eJwLYmBgWK302Uxd5Xv6aqXCiUYKa3YXKuw9DhRmuOnw2mC+3Qq959Yr9L6YbTD5brrF3NKUw83M7Kzn
K6vpAXPtY0KkHVKj5tpnxmZYb0n9ZF6V+ce4KhOkVyNYUSs92DprZRBLIYjv4HXSbWZEmwuILdaZazSn
bX7Yk2a9/peNR+dvquO4UFobcBUkx9eTa7Rzsp6x7gwzy9vzBH1uzH8eHTnfKCV+Lkvhi5mTq6smP+90
mrCml6NvTa9YZ+FEkJ5XG4wmbV5rNOnvyh9Tu5ecXBSycP6m2/N2Hrk97+CpG/O7L/ovDrlRt1L05tv1
gtfub+G4ILn94KmwHeaHRXY+335lx7XVktuPzl+6acMEkFn69+a32N5MaG2/qtbpe1mrZ/p5s6lR5+pm
XTt/acW5S4mbG6/n7rG/Ubjf/ob5Ye4rTaclzndfVD598gLDKBgFQxQAANVAmMQ;

DEFINE COMMENT 3
eJyLZWBguCa0Qu+m4J9jQCYDl/50pUCd6UqJamq6qqq5Rk9VvlsqqbE4X9IO8GY3EPU/aiAZxG6QGduh
n5sgov09XUltZwZIH5+rv2y/i6x6gMuKmIvOa+JBYprWRma/vT+bgdi9JYpa54ub8r1LTy7yLlXa0lui
tt2vZMtBwWLnMyB571JJlf2VDA6WNTEhi1pEa2e16/ULdDPM4e4VXX2sL3FzS3/ZoYMTbq1rmvB50p5J
12prJq2IqZpcamE76ZEWSD//4j8zeJfUzfq1qm7W1zVmUw3X5fblrb9Ulbe+rahwnX2uzSr73M6lHCXx
c1d0LZxjNClmHseiiYseb/Fc+nqX/coN+7I3FO4HmRN08U9W1DnrrOUnm/INjglW/TxkP/vnIcEVFYdF
Vxsck934+FTi5ttnYzZMvBiw/NjVwonM15e0N15nyDt87Wgh83W9/n03Itba3vxx2PZmxG37G7mvnK4b
vRO49OeL8umDP6oONf1sOFD3jWEUjIJBBAB8g6Xy;

