-- HUMAN RESOURCE MACHINE PROGRAM --
-- 16-Absolute-Positivity - SIZE 46/8 - SPEED 24/36 --

-- This solution is level-specific (patterned and quantity-limited input).
-- The input follows the pattern: +-?0-?+
-- Based on 30.25.specific-Mygod.asm

    INBOX   
    OUTBOX  
    INBOX   
    COPYTO   0
    SUB      0
    SUB      0
    OUTBOX  
    INBOX   
    JUMPN    a
    OUTBOX  
    INBOX   
    OUTBOX  
    INBOX   
    COPYTO   0
    SUB      0
    SUB      0
    OUTBOX  
    INBOX   
    JUMPN    c
    OUTBOX  
    INBOX   
    OUTBOX 
    INBOX
a:
    COPYTO   0
    SUB      0
    SUB      0
    OUTBOX  
    INBOX   
    OUTBOX  
    INBOX   
    COPYTO   0
    SUB      0
    SUB      0
    OUTBOX  
    INBOX   
    JUMPN    c
    OUTBOX  
    INBOX   
    OUTBOX 
    INBOX
c:
    COPYTO   0
    SUB      0
    SUB      0
    OUTBOX  
    INBOX   
    OUTBOX  
