-- HUMAN RESOURCE MACHINE PROGRAM --
-- This code is from http://steamcommunity.com/app/375820/discussions/0/405694031552336695/ --
-- The topic also said 24 is possible, but I can't find one --

a:
INBOX 
COPYTO [23]
JUMPZ e
BUMPUP 23
JUMP a
b:
COPYTO 24
c:
d:
COPYFROM [23]
JUMPZ g
OUTBOX 
BUMPUP 23
e:
COPYTO 23
COPYFROM 24
JUMPN d
INBOX 
JUMPZ j
COPYTO 10
COPYFROM [23]
JUMPZ i
SUB 10
JUMPZ c
JUMPN b
COPYFROM 10
f:
OUTBOX 
INBOX 
JUMPZ h
JUMP f
g:
h:
i:
j:


DEFINE LABEL 10
eJwzYGBgOGR7zy7Z9lJVh/X7ZWst//8HCjGUaT2KWKEfE3LI9pr/Fb9r/tpB3wOUQ2NCQHKT04xSxFMD
rl5N3bBvQ/qaJTL5B8O/F9yzEynaa+tX0ubSUDk9fW7V86Jd1c+LBOu74ko7F2tP6tIyONPjHnOmh7dv
ffeaJSBzIud/D4ic3/3CZp77Qpt5HCWz5z2KmLxQ0fHVEg59xxU7lMPWvJfxWy8o93yjlsHSTZN9l25K
yMvesKLr+2q1BRsWcez0nTH7GMMoGAWjgCIAAArGV60;

DEFINE LABEL 23
eJxzZWBg6HUNUdBzVVvQ63ruFZDLkOE+XWm7r5H8vDAj+RsRt1S+RjZp6cfstX0bo+fVFyOYPC3yTxZb
iFZpqV9/BUg9Z1OEVUVNpfWhCgaHsMLvAXvzziao5Ci2Hc2+NuVoNsv8uLyQVbfyb63TLGva8qX2+fb9
rc+3R3Q0bTnTY7TSYWLAhNhJEfWxk6anz5+4Jl55gnUwX89r94iONhfOJmcnkPnavQeFtHsF5fh6EjSD
66oaNMuqjmaXvr4IklPbd9LNbutr97Xrt/jtXakWfXSZUUrasj9ZR5dxlOxdealKZK1ZXcX2e82ce/X6
n+z7MXXR/oNzFu0PWZWx9+g2xS1Kpyes07uyd+WWG4GLJO9Ezr92M3HOyQsMo2AUjCAAAPLWfV4;

DEFINE LABEL 24
eJyzZWBg0BIXtdASn75mneil/UAugx1Lbnm3Xm45iN3qsVj7uHuE1QxTtQWPDM0Pd+sJvt2g0/Rzg87z
P5+0tf6D1CR4uS+cFum+0CeWZT6If6R/hev67hWu1u2PIhJajVLUms3q1Jofz+Vs+rM+oylh88ve/r0P
J4Awx06Q+g2LnJ02LNLrz1s8f3be4v69GxYxnIKIVzU8Wl7VcGjzhsqCXRsqQWKce+/Zce7lvQxir7m8
wpX7yuuLvpf1roD4Sddzy/8/7oqb8exgeMeba/4gsXs3vMtsb1Y17H2yYd/zNyxP/nyAuHkUjIJRAAEA
Okhp6Q;
