-- HUMAN RESOURCE MACHINE PROGRAM --
-- 23-The-Littlest-Number - SIZE 13/13 - SPEED 70/75 --

-- Tweak of @peterfreese solution adds one line but saves one op

    INBOX
    JUMP     d
a:
    COPYFROM 0
    OUTBOX
b:
    INBOX
    JUMP     d
c:
    ADD      0
d:
    COPYTO   0
e:
    INBOX
    JUMPZ    a
    SUB      0
    JUMPN    c
    JUMP     e


DEFINE LABEL 0
eJxTY2BgYDE8t9TNoCoTyGQ4aiDbvMm8MPm9RW7CUpsVMYtsteKkHdqKpjvWzRJ2tp7B7RbT5OHeVerh
3pR/0PN5dLnvzoz8AJ7yrKDHbRrB9rNBZuxL6lpsn5QQDmK7xxuZgWiRIud5gsWFE88Xv44D8XtLukp3
VS+JLK6LCUlovRU0q90oZVb70cJ7rfNb5NrMpjKMglEwCugCABWdN2I;

DEFINE LABEL 1
eJyzZWBg0LPMTcizfN+/yoplfoY1xyIVW96lEY4By/d7BSwHSjMwGYXUbLCYXH3HPqIexJ8Trtg2Jepx
G29sQitrQkzTgUTRWoaktiKO+NK0C9Fr4m+HP49WDXke/TpwTfz6gNK0/ID+iqwgtc7HIaVT7oXVzQqP
dJ73I+Xo/JI0lvmf0uxng8ycnd+2YHa+dRaIfb1ArfN4GUPe3qrv6T+rv6dvrf2TVVB/rtyw/sfU3IbZ
jU+azdJDO7V6zvQwzAGpz5rJcjZnhlk6iL1mxtFC+blGKTfmb0iavNAopW/xzoy2ZV2lnkuv1YounN/y
YmZmN8MoGAWjAA4AIN5nNA;
