-- HUMAN RESOURCE MACHINE PROGRAM --
-- 01-Mail-Room - SIZE 6/6 - SPEED 6/6 --

-- Straightforward. The first level introduces the inbox and outbox commands.

    INBOX   
    OUTBOX  
    INBOX   
    OUTBOX  
    INBOX   
    OUTBOX  

